@@ -166,6 +166,11 @@ void do_cmd_equip(void)
  */
 bool item_tester_hook_wear(object_type *o_ptr)
 {
+	if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		if (!check_monster_wield(wield_slot(o_ptr))) return (FALSE);
+	}
+
 	/* Check for a usable slot */
 	if (wield_slot(o_ptr) >= INVEN_WIELD) return (TRUE);
 
@@ -221,6 +226,58 @@ void do_cmd_wield(void)
 	/* Check the slot */
 	slot = wield_slot(o_ptr);
 
+	/* Snatcher */
+	if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		if (!check_monster_wield(slot))
+		{
+#ifdef JP
+			msg_print("ϤǤʤ");
+#else
+			msg_print("Can not wear/wield it now!");
+#endif
+			return;
+		}
+	}
+
+	/* Where is the item now */
+	if (slot == INVEN_WIELD)
+	{
+#ifdef JP
+		act = "ǷѤ";
+#else
+		act = "You are wielding";
+#endif
+
+	}
+	else if (slot == INVEN_BOW)
+	{
+#ifdef JP
+		act = "ͷѤ";
+#else
+		act = "You are shooting with";
+#endif
+
+	}
+	else if (slot == INVEN_LITE)
+	{
+#ifdef JP
+		act = "ˤ";
+#else
+		act = "Your light source is";
+#endif
+
+	}
+	else
+	{
+#ifdef JP
+		act = "";
+#else
+		act = "You are wearing";
+#endif
+
+	}
+
 	if ((o_ptr->tval == TV_RING) && inventory[INVEN_LEFT].k_idx &&
 		inventory[INVEN_RIGHT].k_idx)
 	{
@@ -240,6 +297,39 @@ void do_cmd_wield(void)
 			return;
 	}
 
+	if (slot == INVEN_WIELD)
+	{
+		if (is_two_handed())
+		{
+			/* Restrict the choices */
+			item_tester_hook = item_tester_hook_melee_weapon;
+
+			/* Choose a ring from the equipment only */
+#ifdef JP
+			q = "ɤȼؤޤ?";
+			s = "äȡ";
+#else
+			q = "Replace which weapon? ";
+			s = "Oops.";
+#endif
+
+			if (!get_item(&slot, q, s, (USE_EQUIP)))
+				return;
+		}
+		else if (inventory[slot].k_idx)
+		{
+			/* Confirm doing two handed combat */
+#ifdef JP
+			if (get_check("ήԤޤ"))
+#else
+			if (get_check("Do you want to do two handed combat?"))
+#endif
+			{
+				slot = INVEN_ARM;
+			}
+		}
+	}
+
 	/* Prevent wielding into a cursed slot */
 	if (cursed_p(&inventory[slot]))
 	{
@@ -371,44 +461,6 @@ sprintf(dummy, "%s{Ƥ}Ȥޤ", o_name);
 	/* Increment the equip counter by hand */
 	equip_cnt++;
 
-	/* Where is the item now */
-	if (slot == INVEN_WIELD)
-	{
-#ifdef JP
-		act = "ǷѤ";
-#else
-		act = "You are wielding";
-#endif
-
-	}
-	else if (slot == INVEN_BOW)
-	{
-#ifdef JP
-		act = "ͷѤ";
-#else
-		act = "You are shooting with";
-#endif
-
-	}
-	else if (slot == INVEN_LITE)
-	{
-#ifdef JP
-		act = "ˤ";
-#else
-		act = "Your light source is";
-#endif
-
-	}
-	else
-	{
-#ifdef JP
-		act = "";
-#else
-		act = "You are wearing";
-#endif
-
-	}
-
 	/* Describe the result */
 	object_desc(o_name, o_ptr, 0);
 
@@ -547,6 +599,27 @@ void do_cmd_takeoff(void)
 	/* Take off the item */
 	(void)inven_takeoff(item, 255);
 
+	/* Swap hands wielding sub weapon */
+	if ((item == INVEN_WIELD) && is_two_handed())
+	{
+		char o_name[MAX_NLEN];
+		object_type *q_ptr = &inventory[INVEN_WIELD];
+
+		o_ptr = &inventory[INVEN_ARM];
+
+		object_copy(q_ptr, o_ptr);
+		object_wipe(o_ptr);
+
+		/* Describe local object */
+		object_desc(o_name, q_ptr, 0);
+
+#ifdef JP
+		msg_format("%s򱦼ǹ", o_name);
+#else
+		msg_format("You are weilding %s in your right hand.", o_name);
+#endif
+	}
+
 	p_ptr->redraw |= (PR_EQUIPPY);
 }
 
