@@ -161,7 +161,8 @@ msg_print("ʤεϿʷˤäƤΤ롪");
 #endif
 
 	}
-	else if (p_ptr->prace == RACE_SKELETON)
+	else if ((p_ptr->prace == RACE_SKELETON) ||
+		((p_ptr->pclass == CLASS_SNATCHER) && (r_info[p_ptr->r_idx].d_char == 's')))
 	{
 		if (!(o_ptr->sval == SV_FOOD_WAYBREAD))
 		{
@@ -191,19 +192,26 @@ msg_print("ʤεϿʷˤäƤΤ롪");
 	}
 	else if ((p_ptr->prace == RACE_GOLEM) ||
 		 (p_ptr->prace == RACE_ZOMBIE) ||
-		 (p_ptr->prace == RACE_SPECTRE))
+		 (p_ptr->prace == RACE_SPECTRE) ||
+		 ((p_ptr->pclass == CLASS_SNATCHER) && (r_info[p_ptr->r_idx].flags3 & (RF3_UNDEAD))))
 	{
 #ifdef JP
-msg_print("ԤοʪϤʤˤȤäƤۤȤɱܤˤʤʤ");
+		msg_print("ԤοʪϤʤˤȤäƤۤȤɱܤˤʤʤ");
 #else
 		msg_print("The food of mortals is poor sustenance for you.");
 #endif
-
 		set_food(p_ptr->food + ((o_ptr->pval) / 20));
 	}
 	else
 	{
-		(void)set_food(p_ptr->food + o_ptr->pval);
+		if (o_ptr->sval == SV_FOOD_WAYBREAD)
+		{
+			(void)set_food(PY_FOOD_MAX - 1);
+		}
+		else
+		{
+			(void)set_food(p_ptr->food + o_ptr->pval);
+		}
 	}
 
 	/* Destroy a food in the pack */
@@ -478,7 +486,7 @@ static void do_cmd_quaff_potion_aux(int item)
 #ifdef JP
 				msg_print("ƬϥåȤ");
 #else
-				msg_print("Your feel your head clear.");
+				msg_print("You feel your head clear.");
 #endif
 
 				p_ptr->redraw |= (PR_MANA);
@@ -810,9 +818,6 @@ static void do_cmd_read_scroll_aux(int item)
 	char        Rumor[1024];
 
 
-	/* Don't save while reading the scroll */
-	can_save = FALSE;
-
 	/* Get the item (in the pack) */
 	if (item >= 0)
 	{
@@ -872,14 +877,14 @@ static void do_cmd_read_scroll_aux(int item)
 		case SV_SCROLL_IDENTIFY:
 		{
 			ident = TRUE;
-			if (!ident_spell(TRUE)) used_up = FALSE;
+			if (!ident_spell()) used_up = FALSE;
 			break;
 		}
 
 		case SV_SCROLL_STAR_IDENTIFY:
 		{
 			ident = TRUE;
-			if (!identify_fully(TRUE)) used_up = FALSE;
+			if (!identify_fully()) used_up = FALSE;
 			break;
 		}
 
@@ -1164,7 +1169,7 @@ take_hit(111+randint1(111), "륹δʪ");
 
 		case SV_SCROLL_RUMOR:
 		{
-			errr err = 0;
+			errr err;
 
 			switch (randint1(20))
 			{
@@ -1262,9 +1267,6 @@ msg_print("ʪϱΩƤƾää");
 	/* Hack -- allow certain scrolls to be "preserved" */
 	if (!used_up)
 	{
-		/* Can save again */
-		can_save = TRUE;
-
 		if (aware) energy_use = 0;
 
 		return;
@@ -1287,9 +1289,6 @@ msg_print("ʪϱΩƤƾää");
 		floor_item_describe(0 - item);
 		floor_item_optimize(0 - item);
 	}
-
-	/* Can save again */
-	can_save = TRUE;
 }
 
 
@@ -1350,6 +1349,38 @@ void do_cmd_read_scroll(void)
 }
 
 
+bool can_use_device(int lev, bool cursed)
+{
+	int chance;
+
+	/* Base chance of success */
+	chance = p_ptr->skill_dev;
+
+	/* Confusion hurts skill */
+	if (p_ptr->confused) chance = chance / 2;
+
+	/* Cursed items are difficult to activate */
+	if (cursed) chance /= 3;
+
+	/* Hight level objects are harder */
+	chance = chance - ((lev > 50) ? 50 : lev);
+
+	/* Give everyone a (slight) chance */
+	if ((chance < USE_DEVICE) && !randint0(USE_DEVICE - chance + 1))
+	{
+		chance = USE_DEVICE;
+	}
+
+	/* Roll for usage */
+	if ((chance < USE_DEVICE) || (randint1(chance) < USE_DEVICE))
+	{
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+
 /*
  * Use a staff.			-RAK-
  *
@@ -1359,7 +1390,7 @@ void do_cmd_read_scroll(void)
  */
 static void do_cmd_use_staff_aux(int item)
 {
-	int         ident, chance, k, lev, aware;
+	int         ident, k, lev, aware;
 	object_type *o_ptr;
 
 
@@ -1401,23 +1432,8 @@ static void do_cmd_use_staff_aux(int item)
 	/* Extract the item level */
 	lev = get_object_level(o_ptr);
 
-	/* Base chance of success */
-	chance = p_ptr->skill_dev;
-
-	/* Confusion hurts skill */
-	if (p_ptr->confused) chance = chance / 2;
-
-	/* Hight level objects are harder */
-	chance = chance - ((lev > 50) ? 50 : lev);
-
-	/* Give everyone a (slight) chance */
-	if ((chance < USE_DEVICE) && (randint0(USE_DEVICE - chance + 1) == 0))
-	{
-		chance = USE_DEVICE;
-	}
-
 	/* Roll for usage */
-	if ((chance < USE_DEVICE) || (randint1(chance) < USE_DEVICE))
+	if (!can_use_device(lev, FALSE))
 	{
 		if (flush_failure) flush();
 #ifdef JP
@@ -1463,7 +1479,7 @@ static void do_cmd_use_staff_aux(int item)
 
 		case SV_STAFF_IDENTIFY:
 		{
-			if (!ident_spell(TRUE)) use_charge = FALSE;
+			if (!ident_spell()) use_charge = FALSE;
 			ident = TRUE;
 			break;
 		}
@@ -1512,7 +1528,7 @@ static void do_cmd_use_staff_aux(int item)
 					if ((y != py) || (x != px)) break;
 				}
 
-				project(0, 0, y, x, damroll(6, 8), GF_LITE_WEAK,
+				project(0, 0, y, x, damroll(6 + p_ptr->lev / 8, 10), GF_LITE_WEAK,
 						  (PROJECT_BEAM | PROJECT_THRU | PROJECT_GRID | PROJECT_KILL));
 			}
 			ident = TRUE;
@@ -1608,7 +1624,7 @@ static void do_cmd_use_staff_aux(int item)
 #ifdef JP
 				msg_print("ƬϥåȤ");
 #else
-				msg_print("Your feel your head clear.");
+				msg_print("You feel your head clear.");
 #endif
 				p_ptr->redraw |= (PR_MANA);
 				p_ptr->window |= (PW_PLAYER);
@@ -1635,10 +1651,6 @@ static void do_cmd_use_staff_aux(int item)
 			{
 				if (set_fast(randint1(30) + 15)) ident = TRUE;
 			}
-			else
-			{
-				(void)set_fast(p_ptr->fast + 5);
-			}
 			break;
 		}
 
@@ -1825,7 +1837,7 @@ void do_cmd_use_staff(void)
  */
 static void do_cmd_aim_wand_aux(int item)
 {
-	int         lev, ident, chance, dir, sval;
+	int         lev, ident, dir, sval;
 	object_type *o_ptr;
 
 
@@ -1866,23 +1878,8 @@ static void do_cmd_aim_wand_aux(int item)
 	/* Get the level */
 	lev = get_object_level(o_ptr);
 
-	/* Base chance of success */
-	chance = p_ptr->skill_dev;
-
-	/* Confusion hurts skill */
-	if (p_ptr->confused) chance = chance / 2;
-
-	/* Hight level objects are harder */
-	chance = chance - ((lev > 50) ? 50 : lev);
-
-	/* Give everyone a (slight) chance */
-	if ((chance < USE_DEVICE) && (randint0(USE_DEVICE - chance + 1) == 0))
-	{
-		chance = USE_DEVICE;
-	}
-
 	/* Roll for usage */
-	if ((chance < USE_DEVICE) || (randint1(chance) < USE_DEVICE))
+	if (!can_use_device(lev, FALSE))
 	{
 		if (flush_failure) flush();
 #ifdef JP
@@ -2008,7 +2005,7 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_DRAIN_LIFE:
 		{
-			if (drain_life(dir, 80 + randint1(50))) ident = TRUE;
+			if (drain_life(dir, 80 + p_ptr->lev)) ident = TRUE;
 			break;
 		}
 
@@ -2020,21 +2017,21 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_STINKING_CLOUD:
 		{
-			fire_ball(GF_POIS, dir, 12, 2);
+			fire_ball(GF_POIS, dir, 12 + p_ptr->lev / 4, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_MAGIC_MISSILE:
 		{
-			fire_bolt_or_beam(20, GF_MISSILE, dir, damroll(2, 6));
+			fire_bolt_or_beam(20, GF_MISSILE, dir, damroll(2 + p_ptr->lev / 10, 6));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_ACID_BOLT:
 		{
-			fire_bolt_or_beam(20, GF_ACID, dir, damroll(6, 8));
+			fire_bolt_or_beam(20, GF_ACID, dir, damroll(6 + p_ptr->lev / 7, 8));
 			ident = TRUE;
 			break;
 		}
@@ -2048,42 +2045,42 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_FIRE_BOLT:
 		{
-			fire_bolt_or_beam(20, GF_FIRE, dir, damroll(7, 8));
+			fire_bolt_or_beam(20, GF_FIRE, dir, damroll(7 + p_ptr->lev / 6, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_COLD_BOLT:
 		{
-			fire_bolt_or_beam(20, GF_COLD, dir, damroll(5, 8));
+			fire_bolt_or_beam(20, GF_COLD, dir, damroll(5 + p_ptr->lev / 8, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_ACID_BALL:
 		{
-			fire_ball(GF_ACID, dir, 60 + randint1(25), 2);
+			fire_ball(GF_ACID, dir, 60 + 3 * p_ptr->lev / 4, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_ELEC_BALL:
 		{
-			fire_ball(GF_ELEC, dir, 40 + randint1(25), 2);
+			fire_ball(GF_ELEC, dir, 40 + 3 * p_ptr->lev / 4, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_FIRE_BALL:
 		{
-			fire_ball(GF_FIRE, dir, 70 + randint1(25), 2);
+			fire_ball(GF_FIRE, dir, 70 + 3 * p_ptr->lev / 4, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_WAND_COLD_BALL:
 		{
-			fire_ball(GF_COLD, dir, 50 + randint1(25), 2);
+			fire_ball(GF_COLD, dir, 50 + 3 * p_ptr->lev / 4, 2);
 			ident = TRUE;
 			break;
 		}
@@ -2100,6 +2097,7 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_DRAGON_FIRE:
 		{
+			sound(SOUND_BREATH);
 			fire_ball(GF_FIRE, dir, 200, -3);
 			ident = TRUE;
 			break;
@@ -2107,6 +2105,7 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_DRAGON_COLD:
 		{
+			sound(SOUND_BREATH);
 			fire_ball(GF_COLD, dir, 180, -3);
 			ident = TRUE;
 			break;
@@ -2114,6 +2113,8 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_DRAGON_BREATH:
 		{
+			sound(SOUND_BREATH);
+
 			switch (randint1(5))
 			{
 				case 1:
@@ -2153,7 +2154,7 @@ static void do_cmd_aim_wand_aux(int item)
 
 		case SV_WAND_DISINTEGRATE: /* Disintegrate */
 		{
-			fire_ball(GF_DISINTEGRATE, dir, 200 + randint1(100), 2);
+			fire_ball(GF_DISINTEGRATE, dir, 200 + p_ptr->lev * 2, 2);
 			ident = TRUE;
 			break;
 		}
@@ -2165,7 +2166,8 @@ static void do_cmd_aim_wand_aux(int item)
 #else
 			msg_print("You launch a rocket!");
 #endif
-			fire_ball(GF_ROCKET, dir, 250 + randint1(150), 2);
+			sound(SOUND_ROCKET);
+			fire_ball(GF_ROCKET, dir, 250 + p_ptr->lev * 3, 2);
 			ident = TRUE;
 			break;
 		}
@@ -2242,7 +2244,7 @@ void do_cmd_aim_wand(void)
  */
 static void do_cmd_zap_rod_aux(int item)
 {
-	int         ident, chance, dir, lev, aware;
+	int         ident, dir, lev, aware;
 	object_type *o_ptr;
 
 	/* Hack -- let perception get aborted */
@@ -2293,23 +2295,8 @@ static void do_cmd_zap_rod_aux(int item)
 	/* Extract the item level */
 	lev = get_object_level(o_ptr);
 
-	/* Base chance of success */
-	chance = p_ptr->skill_dev;
-
-	/* Confusion hurts skill */
-	if (p_ptr->confused) chance = chance / 2;
-
-	/* Hight level objects are harder */
-	chance = chance - ((lev > 50) ? 50 : lev);
-
-	/* Give everyone a (slight) chance */
-	if ((chance < USE_DEVICE) && (randint0(USE_DEVICE - chance + 1) == 0))
-	{
-		chance = USE_DEVICE;
-	}
-
 	/* Roll for usage */
-	if ((chance < USE_DEVICE) || (randint1(chance) < USE_DEVICE))
+	if (!can_use_device(lev, FALSE))
 	{
 		if (flush_failure) flush();
 #ifdef JP
@@ -2372,7 +2359,7 @@ static void do_cmd_zap_rod_aux(int item)
 		case SV_ROD_IDENTIFY:
 		{
 			ident = TRUE;
-			if (!ident_spell(FALSE)) use_charge = FALSE;
+			if (!ident_spell()) use_charge = FALSE;
 			break;
 		}
 
@@ -2456,8 +2443,7 @@ static void do_cmd_zap_rod_aux(int item)
 
 		case SV_ROD_PESTICIDE:
 		{
-			fire_ball(GF_POIS, dir, 12, 3);
-			ident = TRUE;
+			if (dispel_monsters(4)) ident = TRUE;
 			break;
 		}
 
@@ -2499,7 +2485,7 @@ static void do_cmd_zap_rod_aux(int item)
 
 		case SV_ROD_DRAIN_LIFE:
 		{
-			if (drain_life(dir, 75 + randint1(75))) ident = TRUE;
+			if (drain_life(dir, 75 + 3 * p_ptr->lev / 2)) ident = TRUE;
 			break;
 		}
 
@@ -2511,56 +2497,56 @@ static void do_cmd_zap_rod_aux(int item)
 
 		case SV_ROD_ACID_BOLT:
 		{
-			fire_bolt_or_beam(10, GF_ACID, dir, damroll(7, 8));
+			fire_bolt_or_beam(10, GF_ACID, dir, damroll(7 + p_ptr->lev / 7, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_ELEC_BOLT:
 		{
-			fire_bolt_or_beam(10, GF_ELEC, dir, damroll(5, 8));
+			fire_bolt_or_beam(10, GF_ELEC, dir, damroll(5 + p_ptr->lev / 9, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_FIRE_BOLT:
 		{
-			fire_bolt_or_beam(10, GF_FIRE, dir, damroll(8, 8));
+			fire_bolt_or_beam(10, GF_FIRE, dir, damroll(8 + p_ptr->lev / 6, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_COLD_BOLT:
 		{
-			fire_bolt_or_beam(10, GF_COLD, dir, damroll(6, 8));
+			fire_bolt_or_beam(10, GF_COLD, dir, damroll(6 + p_ptr->lev / 8, 8));
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_ACID_BALL:
 		{
-			fire_ball(GF_ACID, dir, 60 + randint1(50), 2);
+			fire_ball(GF_ACID, dir, 60 + p_ptr->lev, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_ELEC_BALL:
 		{
-			fire_ball(GF_ELEC, dir, 40 + randint1(50), 2);
+			fire_ball(GF_ELEC, dir, 40 + p_ptr->lev, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_FIRE_BALL:
 		{
-			fire_ball(GF_FIRE, dir, 70 + randint1(50), 2);
+			fire_ball(GF_FIRE, dir, 70 + p_ptr->lev, 2);
 			ident = TRUE;
 			break;
 		}
 
 		case SV_ROD_COLD_BALL:
 		{
-			fire_ball(GF_COLD, dir, 50 + randint1(50), 2);
+			fire_ball(GF_COLD, dir, 50 + p_ptr->lev, 2);
 			ident = TRUE;
 			break;
 		}
@@ -2770,26 +2756,8 @@ static void do_cmd_activate_aux(int item)
 	/* Hack -- use artifact level instead */
 	if (artifact_p(o_ptr)) lev = a_info[o_ptr->name1].level;
 
-	/* Base chance of success */
-	chance = p_ptr->skill_dev;
-
-	/* Confusion hurts skill */
-	if (p_ptr->confused) chance /= 2;
-
-	/* Cursed items are difficult to activate */
-	if (o_ptr->ident & IDENT_CURSED) chance /= 3;
-
-	/* Hight level objects are harder */
-	chance = chance - ((lev > 50) ? 50 : lev);
-
-	/* Give everyone a (slight) chance */
-	if ((chance < USE_DEVICE) && (randint0(USE_DEVICE - chance + 1) == 0))
-	{
-		chance = USE_DEVICE;
-	}
-
 	/* Roll for usage */
-	if ((chance < USE_DEVICE) || (randint1(chance) < USE_DEVICE))
+	if (!can_use_device(lev, (bool)(o_ptr->ident & IDENT_CURSED)))
 	{
 		if (flush_failure) flush();
 #ifdef JP
@@ -3170,8 +3138,8 @@ static void do_cmd_activate_aux(int item)
 			{
 				if(one_in_(5))
 				{
-					if(one_in_(100)) identify_fully(FALSE);
-					else ident_spell(FALSE);
+					if (one_in_(100)) (void)identify_fully();
+					else (void)ident_spell();
 				}
 				else
 				{
@@ -3186,6 +3154,18 @@ static void do_cmd_activate_aux(int item)
 				}
 				break;
 			}
+			case ART_PITCH_DARK_NIGHT:
+			{
+#ifdef JP
+				msg_print("ߥåȤϼ˵...");
+#else
+				msg_print("The amulet glows intensely black...");
+#endif
+				if (!get_aim_dir(&dir)) return;
+				fire_ball(GF_DARK, dir, 250, 3);
+				o_ptr->timeout = randint0(150) + 150;
+				break;
+			}
 		}
 
 		/* Window stuff */
@@ -3206,9 +3186,63 @@ static void do_cmd_activate_aux(int item)
 				break;
 			case EGO_MAGICAL_SHOT:
 				if (!get_aim_dir(&dir)) break;
-				fire_bolt(GF_ARROW, dir, 50);
-				o_ptr->timeout = randint0(10) + 10;
+				fire_bolt(GF_ARROW, dir, (50 + p_ptr->lev * 2));
+				o_ptr->timeout = randint0(7) + 7;
 				break;
+			case EGO_BRAND_ACID:
+				if (!get_aim_dir(&dir)) break;
+				fire_ball(GF_ACID, dir, 100, 2);
+				(void)set_oppose_acid(p_ptr->oppose_acid + randint1(20) + 20);
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			case EGO_BRAND_COLD:
+				if (!get_aim_dir(&dir)) break;
+				fire_ball(GF_COLD, dir, 100, 2);
+				(void)set_oppose_cold(p_ptr->oppose_cold + randint1(20) + 20);
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			case EGO_BRAND_FIRE:
+				if (!get_aim_dir(&dir)) break;
+				fire_ball(GF_FIRE, dir, 100, 2);
+				(void)set_oppose_fire(p_ptr->oppose_fire + randint1(20) + 20);
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			case EGO_BRAND_ELEC:
+				if (!get_aim_dir(&dir)) break;
+				fire_ball(GF_ELEC, dir, 100, 2);
+				(void)set_oppose_elec(p_ptr->oppose_elec + randint1(20) + 20);
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			case EGO_BRAND_POIS:
+				if (!get_aim_dir(&dir)) break;
+				fire_ball(GF_POIS, dir, 100, 2);
+				(void)set_oppose_pois(p_ptr->oppose_pois + randint1(20) + 20);
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			case EGO_WEAP_LITE:
+			{
+				int num = damroll(5, 3);
+				int y, x;
+				int attempts;
+
+				for (k = 0; k < num; k++)
+				{
+					attempts = 1000;
+
+					while (attempts--)
+					{
+						scatter(&y, &x, py, px, 4, 0);
+						if (!cave_floor_bold(y, x)) continue;
+						if ((y != py) || (x != px)) break;
+					}
+
+					project(0, 0, y, x, damroll(6, 8), GF_LITE_WEAK,
+							  (PROJECT_BEAM | PROJECT_THRU | PROJECT_GRID | PROJECT_KILL));
+				}
+
+				o_ptr->timeout = randint0(50) + 50;
+				break;
+			}
 		}
 
 		/* Window stuff */
@@ -3435,7 +3469,7 @@ static void do_cmd_activate_aux(int item)
 		{
 			case SV_RING_ACID:
 			{
-				fire_ball(GF_ACID, dir, 50, 2);
+				fire_ball(GF_ACID, dir, 100, 2);
 				(void)set_oppose_acid(p_ptr->oppose_acid + randint1(20) + 20);
 				o_ptr->timeout = randint0(50) + 50;
 				break;
@@ -3443,7 +3477,7 @@ static void do_cmd_activate_aux(int item)
 
 			case SV_RING_ICE:
 			{
-				fire_ball(GF_COLD, dir, 50, 2);
+				fire_ball(GF_COLD, dir, 100, 2);
 				(void)set_oppose_cold(p_ptr->oppose_cold + randint1(20) + 20);
 				o_ptr->timeout = randint0(50) + 50;
 				break;
@@ -3451,7 +3485,7 @@ static void do_cmd_activate_aux(int item)
 
 			case SV_RING_FLAMES:
 			{
-				fire_ball(GF_FIRE, dir, 50, 2);
+				fire_ball(GF_FIRE, dir, 100, 2);
 				(void)set_oppose_fire(p_ptr->oppose_fire + randint1(20) + 20);
 				o_ptr->timeout = randint0(50) + 50;
 				break;
@@ -3459,7 +3493,7 @@ static void do_cmd_activate_aux(int item)
 
 			case SV_RING_ELEC:
 			{
-				fire_ball(GF_ELEC, dir, 50, 2);
+				fire_ball(GF_ELEC, dir, 100, 2);
 				(void)set_oppose_elec(p_ptr->oppose_elec + randint1(20) + 20);
 				o_ptr->timeout = randint0(50) + 50;
 				break;
@@ -3695,7 +3729,7 @@ msg_print("𤷤Ƥɤʤ");
 		case TV_ARROW:
 		case TV_BOLT:
 		{
-			do_cmd_fire_aux(item, &inventory[INVEN_BOW]);
+			(void)do_cmd_fire_aux(item, &inventory[INVEN_BOW]);
 			break;
 		}
 
