@@ -3655,6 +3655,13 @@ void gain_exp(s32b amount)
 	/* Gain some experience */
 	p_ptr->exp += amount;
 
+	/* Snatchers can not gain experieces which are over maximum level of snatched body */
+	if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		if (p_ptr->exp > (player_exp[SN_MAX_LEVEL - 1] * p_ptr->expfact / 100L - 1L))
+			p_ptr->exp = (player_exp[SN_MAX_LEVEL - 1] * p_ptr->expfact / 100L - 1L);
+	}
+
 	/* Slowly recover from experience drainage */
 	if (p_ptr->exp < p_ptr->max_exp)
 	{
