@@ -190,8 +190,7 @@ void place_closed_door(int y, int x)
 void vault_objects(int y, int x, int num)
 {
 	int dummy = 0;
-	int i = 0, j = y, k = x;
-
+	int i, j = y, k = x;
 
 	/* Attempt to place 'num' objects */
 	for (; num > 0; --num)
@@ -251,7 +250,7 @@ msg_print("ٹˤ˥ƥ֤ޤ");
  */
 void vault_trap_aux(int y, int x, int yd, int xd)
 {
-	int count = 0, y1 = y, x1 = x;
+	int count, y1 = y, x1 = x;
 	int dummy = 0;
 
 	/* Place traps */
