@@ -441,12 +441,7 @@ static errr init_info(cptr filename, header *head,
 	/*** Load the binary image file ***/
 
 	/* Build the filename */
-#ifdef JP
-	path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s_j.raw", filename));
-#else
 	path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s.raw", filename));
-#endif
-
 
 	/* Attempt to open the "raw" file */
 	fd = fd_open(buf, O_RDONLY);
@@ -456,11 +451,7 @@ static errr init_info(cptr filename, header *head,
 	{
 #ifdef CHECK_MODIFICATION_TIME
 
-#ifdef JP
-		err = check_modification_date(fd, format("%s_j.txt", filename));
-#else
 		err = check_modification_date(fd, format("%s.txt", filename));
-#endif
 
 #endif /* CHECK_MODIFICATION_TIME */
 
@@ -493,18 +484,14 @@ static errr init_info(cptr filename, header *head,
 
 		/* Build the filename */
 
-#ifdef JP
-		path_build(buf, sizeof(buf), ANGBAND_DIR_EDIT, format("%s_j.txt", filename));
-#else
 		path_build(buf, sizeof(buf), ANGBAND_DIR_EDIT, format("%s.txt", filename));
-#endif
 
 		/* Open the file */
 		fp = my_fopen(buf, "r");
 
 		/* Parse it */
 #ifdef JP
-		if (!fp) quit(format("'%s_j.txt'ե򥪡ץǤޤ", filename));
+		if (!fp) quit(format("'%s.txt'ե򥪡ץǤޤ", filename));
 #else
 		if (!fp) quit(format("Cannot open '%s.txt' file.", filename));
 #endif
@@ -555,12 +542,7 @@ static errr init_info(cptr filename, header *head,
 		FILE_TYPE(FILE_TYPE_DATA);
 
 		/* Build the filename */
-#ifdef JP
-		path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s_j.raw", filename));
-#else
 		path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s.raw", filename));
-#endif
-
 
 		/* Kill the old file */
 		(void)fd_kill(buf);
@@ -603,19 +585,14 @@ static errr init_info(cptr filename, header *head,
 		/*** Load the binary image file ***/
 
 		/* Build the filename */
-#ifdef JP
-		path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s_j.raw", filename));
-#else
 		path_build(buf, sizeof(buf), ANGBAND_DIR_DATA, format("%s.raw", filename));
-#endif
-
 
 		/* Attempt to open the "raw" file */
 		fd = fd_open(buf, O_RDONLY);
 
 		/* Process existing "raw" file */
 #ifdef JP
-		if (fd < 0) quit(format("'%s_j.raw'եɤǤޤ", filename));
+		if (fd < 0) quit(format("'%s.raw'եɤǤޤ", filename));
 #else
 		if (fd < 0) quit(format("Cannot load '%s.raw' file.", filename));
 #endif
@@ -629,7 +606,7 @@ static errr init_info(cptr filename, header *head,
 
 		/* Error */
 #ifdef JP
-		if (err) quit(format("'%s_j.raw'եϤǤޤ", filename));
+		if (err) quit(format("'%s.raw'եϤǤޤ", filename));
 #else
 		if (err) quit(format("Cannot parse '%s.raw' file.", filename));
 #endif
@@ -1383,12 +1360,7 @@ static byte store_table[MAX_STORES][STORE_CHOICES][2] =
 static errr init_misc(void)
 {
 	/* Initialize the values */
-#ifdef JP
-	process_dungeon_file("misc_j.txt", 0, 0, 0, 0);
-#else
 	process_dungeon_file("misc.txt", 0, 0, 0, 0);
-#endif
-
 
 	return 0;
 }
@@ -1423,24 +1395,20 @@ static errr init_towns(void)
 			if (i > 1 && j == STORE_HOME) continue;
 
 			/* Assume full stock */
-#ifdef JP
-		/*
-		 * 椬Ȥ 20 ڡޤǻȤ뱣ǽΤν
-		 * ץͭǤ⤽ǤʤƤڡ
-		 * äƤ
-		 * ڤǤϳΤǣڡˡ
-		 */
-		if (j == STORE_HOME)
-		{
-			st_ptr->stock_size = (STORE_INVEN_MAX * 10);
-		}
-		else
-		{
-			st_ptr->stock_size = STORE_INVEN_MAX;
-		}
-#else
-			st_ptr->stock_size = STORE_INVEN_MAX;
-#endif
+			/*
+			* 椬Ȥ 20 ڡޤǻȤ뱣ǽΤν
+			* ץͭǤ⤽ǤʤƤڡ
+			* äƤ
+			* ڤǤϳΤǣڡˡ
+			*/
+			if (j == STORE_HOME)
+			{
+				st_ptr->stock_size = (STORE_INVEN_MAX * 10);
+			}
+			else
+			{
+				st_ptr->stock_size = STORE_INVEN_MAX;
+			}
 
 
 			/* Allocate the stock */
