@@ -860,6 +860,12 @@ static void rd_options(void)
 	rd_byte(&b);
 	hitpoint_warn = b;
 
+	if (!k_older_than(1, 1, 2))
+	{
+		/* Read "spellpoint_warn" */
+		rd_byte(&b);
+		spellpoint_warn = b;
+	}
 
 	/*** Cheating options ***/
 
@@ -1181,13 +1187,13 @@ static void rd_extra(void)
 	rd_s16b(&p_ptr->tim_xtra7);
 	rd_s16b(&p_ptr->chaos_patron);
 	rd_u32b(&p_ptr->muta);
-	rd_u32b(&p_ptr->xtra1);
-	rd_u32b(&p_ptr->xtra2);
+	rd_u32b(&p_ptr->concent);
+	rd_u32b(&p_ptr->r_idx);
 	if (k_older_than(0, 7, 2))
 	{
 		p_ptr->muta = 0;
-		p_ptr->xtra1 = 0;
-		p_ptr->xtra2 = 0;
+		p_ptr->concent = 0;
+		p_ptr->r_idx = 0;
 	}
 
 	if (!(sf_version < 5) && k_older_than(0, 4, 3))
@@ -1366,6 +1372,23 @@ static errr rd_inventory(void)
 		}
 	}
 
+	if (k_older_than(1, 1, 2))
+	{
+		int i;
+
+		q_ptr = &forge;
+		object_wipe(q_ptr);
+
+		if (inventory[INVEN_OUTER].k_idx) object_copy(q_ptr, &inventory[INVEN_OUTER]);
+
+		for (i = INVEN_OUTER; i > INVEN_ARM; i--)
+		{
+			object_copy(&inventory[i], &inventory[i - 1]);
+		}
+
+		object_copy(&inventory[INVEN_ARM], q_ptr);
+	}
+
 	/* Success */
 	return (0);
 }
