@@ -3517,14 +3517,6 @@ void process_monsters(int th_energy)
 	byte    old_r_cast_inate = 0;
 	byte    old_r_cast_spell = 0;
 
-	int old_total_friends = total_friends; 
-	s32b old_friend_align = friend_align;
-
-	/* Clear some variables */
-	total_friends = 0;
-	total_friend_levels = 0;
-	friend_align = 0;
-
 	/* Clear monster fighting indicator */
 	mon_fight = FALSE;
 
@@ -3574,23 +3566,6 @@ void process_monsters(int th_energy)
 		/* Ignore "dead" monsters */
 		if (!m_ptr->r_idx) continue;
 
-		/* Calculate "upkeep" for pets */
-		if (is_pet(m_ptr))
-		{
-			total_friends++;
-			total_friend_levels += r_ptr->level;
-
-			/* Determine pet alignment */
-			if (r_ptr->flags3 & RF3_GOOD)
-			{
-				friend_align += r_ptr->level;
-			}
-			else if (r_ptr->flags3 & RF3_EVIL)
-			{
-				friend_align -= r_ptr->level;
-			}
-		}
-
 		/* Handle "fresh" monsters */
 		if (m_ptr->mflag & MFLAG_BORN)
 		{
@@ -3623,14 +3598,8 @@ void process_monsters(int th_energy)
 		/* Assume no move */
 		test = FALSE;
 
-		/* Allow more activity with pets around */
-		if (old_total_friends)
-		{
-			test = TRUE;
-		}
-
 		/* Handle "sensing radius" */
-		if (m_ptr->cdis <= r_ptr->aaf)
+		if (m_ptr->cdis <= (is_pet(m_ptr) ? MIN(MAX_SIGHT, r_ptr->aaf) : r_ptr->aaf))
 		{
 			/* We can "sense" the player */
 			test = TRUE;
@@ -3706,8 +3675,6 @@ void process_monsters(int th_energy)
 			p_ptr->window |= (PW_MONSTER);
 		}
 	}
-
-	if (old_friend_align != friend_align) p_ptr->update |= (PU_BONUS);
 }
 #ifdef JP
 /* XTRA HACK THEWORLD */
