@@ -12,6 +12,8 @@
 
 #include "angband.h"
 
+#define MAX_MINDCRAFT_POWERS  13
+
 static const char *mind_tips[MAX_MINDCRAFT_POWERS] =
 {
 #ifdef JP
@@ -29,19 +31,19 @@ static const char *mind_tips[MAX_MINDCRAFT_POWERS] =
 	"εġ󥹥̿椹ȡ01.5񤹤롣񹳤ʤСMP롣",
 	"̵ڤʥͥ륮Υӡġ",
 #else
-	"fires a ball of lightning.",
-	"detects visible monsters in your vicinity and more and more. detects traps and doors at level 5, invisible monsters at level 15, items at level 30. And magic mapping at level 20. lights and know the whole level at level 45. gives telepathy at level 25",
-	"teleport short distance. or teleport to given location at level 40.",
-	"teleport long distance.",
-	"stuns, confuses or scares a monster. or attempts to charm all monsters in sight at level 30.",
-	"fires a ball of sound.",
-	"gives stone skin and some resistance to elements for a while. The level increased, the more number of resistances given.",
-	"gives feeling of an item. or identify an item at level 25.",
-	"generate a ball centered on you which inflict monster with PSI damage. or inflict all monsters with PSI damage at level 25",
-	"removes fear and stun. gives heroism and speed. heals HP a little unless you already have heroism and temporal speed boost.",
-	"pulls a distant item close to you.",
-	"fires a ball which damages monsters and absorbs monsters' mind power. absorbing is takes more turns which from 0 to 1.5.",
-	"fires a beam of pure energy which penetrate the invulnerability barrier.",
+	"Fires a ball of lightning.",
+	"Detects visible monsters in your vicinity and more and more. Detects traps and doors at level 5, invisible monsters at level 15, items at level 30. And magic mapping at level 20. Lights and know the whole level at level 45. Gives telepathy at level 25.",
+	"Teleport short distance. Or teleport to given location at level 40.",
+	"Teleport long distance.",
+	"Stuns, confuses or scares a monster. Or attempts to charm all monsters in sight at level 30.",
+	"Fires a ball of sound.",
+	"Gives stone skin and some resistance to elements for a while. The level increased, the more number of resistances given.",
+	"Gives feeling of an item. Or identify an item at level 25.",
+	"Generate a ball centered on you which inflict monster with PSI damage. Or inflict all monsters with PSI damage at level 25.",
+	"Removes fear and stun. Gives heroism and speed. Heals HP a little unless you already have heroism and temporal speed boost.",
+	"Pulls a distant item close to you.",
+	"Fires a ball which damages monsters and absorbs monsters' mind power. Absorbing is takes more turns which from 0 to 1.5.",
+	"Fires a beam of pure energy which penetrate the invulnerability barrier.",
 #endif
 };
 
@@ -121,6 +123,50 @@ void mindcraft_info(char *p, int power)
 }
 
 
+void display_mind_list(void)
+{
+	int             i;
+	int             y = 1;
+	int             x = 1;
+	int             plev = p_ptr->lev;
+	int             chance;
+	mindcraft_power spell;
+	char            comment[80];
+	char            psi_desc[80];
+
+	/* Display a list of spells */
+	prt("", y, x);
+#ifdef JP
+	put_str("̾", y, x + 5);
+	put_str("Lv   MP Ψ ", y, x + 35);
+#else
+	put_str("Name", y, x + 5);
+	put_str("Lv Mana Fail Info", y, x + 35);
+#endif
+
+	/* Dump the spells */
+	for (i = 0; i < MAX_MINDCRAFT_POWERS; i++)
+	{
+		/* Access the available spell */
+		spell = mindcraft_powers[i];
+		if (spell.min_lev > plev) break;
+
+		chance = get_spell_chance(spell.fail, spell.min_lev, spell.mana_cost);
+
+		/* Get info */
+		mindcraft_info(comment, i);
+
+		/* Dump the spell */
+		sprintf(psi_desc, "  %c) %-30s%2d %4d %3d%%%s",
+			I2A(i), spell.name,
+			spell.min_lev, spell.mana_cost, chance, comment);
+
+		Term_putstr(x, y + i + 1, -1, TERM_WHITE, psi_desc);
+	}
+	return;
+}
+
+
 /*
  * Allow user to choose a mindcrafter power.
  *
@@ -141,9 +187,9 @@ static int get_mindcraft_power(int *sn, bool only_browse)
 	int             num = 0;
 	int             y = 1;
 	int             x = 20;
-	int             minfail = 0;
+	int             minfail;
 	int             plev = p_ptr->lev;
-	int             chance = 0;
+	int             chance;
 	int             ask;
 	char            choice;
 	char            out_val[160];
@@ -376,7 +422,7 @@ static int get_mindcraft_power(int *sn, bool only_browse)
  */
 static bool cast_mindcrafter_spell(int spell)
 {
-	int b = 0;
+	int b;
 	int dir;
 	int plev = p_ptr->lev;
 
@@ -471,11 +517,8 @@ static bool cast_mindcrafter_spell(int spell)
 		break;
 	case 7:
 		/* Psychometry */
-		if (plev < 25)
-			return psychometry();
-		else
-			return ident_spell(FALSE);
-		break;
+		if (plev < 25) return psychometry();
+		else return ident_spell();
 	case 8:
 		/* Mindwave */
 #ifdef JP
@@ -561,7 +604,7 @@ void do_cmd_mindcraft(void)
 {
 	int             n = 0;
 	int             chance;
-	int             minfail = 0;
+	int             minfail;
 	int             plev = p_ptr->lev;
 	int             old_csp = p_ptr->csp;
 	mindcraft_power spell;
@@ -795,6 +838,4 @@ void do_cmd_mind_browse(void)
 			line++;
 		}
 	}
-
-	screen_load();
 }
