@@ -26,6 +26,150 @@ struct power_desc_type
 };
 
 
+/* Hit and Away */
+static bool hit_and_away(void)
+{
+	int dir;
+	int x, y;
+
+	if (!get_rep_dir(&dir)) return FALSE;
+
+	y = py + ddy[dir];
+	x = px + ddx[dir];
+
+	if (!cave[y][x].m_idx)
+	{
+#ifdef JP
+		msg_print("ˤϥ󥹥Ϥޤ");
+#else
+		msg_print("You don't see any monster in this direction");
+#endif
+		return (FALSE);
+	}
+
+	py_attack(y, x);
+
+	if (randint0(p_ptr->skill_dis) < 7)
+#ifdef JP
+		msg_print("ޤƨʤä");
+#else
+		msg_print("You are failed to run away.");
+#endif
+	else teleport_player(30);
+
+	return (TRUE);
+}
+
+
+#define cave_wall_bold(Y, X) \
+	((cave[Y][X].feat >= FEAT_SECRET) && \
+	(cave[Y][X].feat <= FEAT_PERM_SOLID))
+
+
+/*
+ * Go to an opposite empty floor over a wall.
+ */
+static bool jump_wall(void)
+{
+	int nx = px;
+	int ny = py;
+	int tx, ty;
+	int dir;
+
+	project_length = 3;
+	if (!get_aim_dir(&dir)) return FALSE;
+
+	/* Predict the "target" location */
+	ty = py + 2 * ddy[dir];
+	tx = px + 2 * ddx[dir];
+
+	/* Check for "target request" */
+	if ((dir == 5) && target_okay())
+	{
+		tx = target_col;
+		ty = target_row;
+	}
+
+	project_length = 0;
+	mmove2(&ny, &nx, py, px, ty, tx);
+
+	if (!cave_wall_bold(ny, nx) || !in_bounds(ny, nx))
+	{
+#ifdef JP
+		msg_print("Ķ٤ɤޤ");
+#else
+		msg_print("No wall for passing.");
+#endif
+		return FALSE;
+	}
+
+	mmove2(&ny, &nx, py, px, ty, tx);
+
+	if (!in_bounds(ny, nx) || (cave[ny][nx].info & CAVE_ICKY) ||
+		((cave[ny][nx].info & CAVE_MARK) && cave_wall_bold(ny, nx)))
+	{
+#ifdef JP
+		msg_print("ؤϰưǤޤ");
+#else
+		msg_print("Can not move here.");
+#endif
+		return FALSE;
+	}
+
+	if (cave[ny][nx].m_idx)
+	{
+		monster_type *m_ptr = &m_list[cave[ny][nx].m_idx];
+
+		if (is_seen(m_ptr))
+		{
+#ifdef JP
+			msg_print("ؤϰưǤޤ");
+#else
+			msg_print("Can not move here.");
+#endif
+			return FALSE;
+		}
+	}
+
+	/* Sound */
+	sound(SOUND_TELEPORT);
+
+	if (cave_wall_bold(ny, nx) || (cave[ny][nx].info & CAVE_ICKY) || cave[ny][nx].m_idx || one_in_(10))
+	{
+#ifdef JP
+		msg_print("ư˼Ԥޤ");
+#else
+		msg_print("Fail to pass the wall.");
+#endif
+	}
+	else
+	{
+		int ox = px;
+		int oy = py;
+
+		px = nx;
+		py = ny;
+		lite_spot(oy, ox);
+		lite_spot(py, px);
+		forget_flow();
+
+		/* Update stuff */
+		p_ptr->update |= (PU_VIEW | PU_LITE | PU_FLOW | PU_MON_LITE);
+
+		/* Update the monsters */
+		p_ptr->update |= (PU_DISTANCE);
+
+		/* Window stuff */
+		p_ptr->window |= (PW_OVERHEAD | PW_DUNGEON);
+
+		/* Handle stuff XXX XXX XXX */
+		handle_stuff();
+	}
+
+	return (TRUE);
+}
+
+
 /*
  * Returns the chance to activate a racial power/mutation
  */
@@ -185,7 +329,7 @@ static bool do_cmd_shield_bash(void)
 	o_ptr = &inventory[INVEN_ARM];
 
 	/* No shield on arm, no bash.  */
-	if (!o_ptr->k_idx)
+	if (!o_ptr->k_idx || is_two_handed())
 	{
 #ifdef JP
 		msg_print("Ƥʤ");
@@ -454,6 +598,144 @@ static bool do_cmd_identify_bows_and_ammos(void)
 	return (TRUE);
 }
 
+static bool item_tester_hook_arrow(object_type *o_ptr)
+{
+	if (o_ptr->tval == TV_ARROW) return (TRUE);
+
+	return (FALSE);
+}
+
+static bool do_cmd_arrow_rain(void)
+{
+	int x, y, tx, ty;
+	int ny, nx;
+	int tdam, tmul;
+	int i, dir = 0;
+	int item;
+	int n = 5 + randint1(3);
+	cptr q, s;
+	object_type *o_ptr, *q_ptr, *j_ptr;
+	object_type forge;
+	cave_type *c_ptr;
+
+	o_ptr = &inventory[INVEN_BOW];
+	item_tester_hook = item_tester_hook_arrow;
+
+	if (!((o_ptr->tval == TV_BOW) &&
+		((o_ptr->sval == SV_LONG_BOW) || (o_ptr->sval == SV_SHORT_BOW))))
+	{
+#ifdef JP
+		msg_print("ݤƤʤ");
+#else
+		msg_print("You wield no bows!");
+#endif
+		return (FALSE);
+	}
+
+	/* Get an item */
+#ifdef JP
+	q = "ɤޤ? ";
+	s = "ȯͤ륢ƥबޤ";
+#else
+	q = "Fire which item? ";
+	s = "You have nothing to fire.";
+#endif
+
+	if (!get_item(&item, q, s, (USE_EQUIP | USE_INVEN | USE_FLOOR))) return (FALSE);
+
+	/* Access the item (if in the pack) */
+	if (item >= 0)
+	{
+		q_ptr = &inventory[item];
+	}
+	else
+	{
+		q_ptr = &o_list[0 - item];
+	}
+
+	if (!get_aim_dir(&dir)) return FALSE;
+
+	tdam = damroll(q_ptr->dd, q_ptr->ds) + o_ptr->to_d + q_ptr->to_d;
+	tmul = bow_tmul(o_ptr->sval);
+
+	/* Get extra "power" from "extra might" */
+	if (p_ptr->xtra_might) tmul++;
+
+	tmul = tmul * (100 + (int)(adj_str_td[p_ptr->stat_ind[A_STR]]) - 128);
+
+	/* Boost the damage */
+	tdam *= tmul;
+	tdam /= 100;
+
+	/* Use the given direction */
+	tx = px + 99 * ddx[dir];
+	ty = py + 99 * ddy[dir];
+
+	/* Hack -- Use an actual "target" */
+	if ((dir == 5) && target_okay())
+	{
+		tx = target_col;
+		ty = target_row;
+	}
+
+	x = px;
+	y = py;
+
+	while (1)
+	{
+		bool flag = FALSE;
+
+		/* Hack -- Stop at the target */
+		if ((y == ty) && (x == tx)) break;
+
+		ny = y;
+		nx = x;
+		mmove2(&ny, &nx, py, px, ty, tx);
+
+		/* Stop at maximum range */
+		if (MAX_RANGE <= distance(py, px, ny, nx)) break;
+
+		/* Stopped by walls/doors */
+		c_ptr = &cave[ny][nx];
+		if (!cave_floor_grid(c_ptr) && !c_ptr->m_idx) break;
+
+		/* Save the new location */
+		x = nx;
+		y = ny;
+
+		/* Stopped by monsters */
+		if ((dir != 5) && cave[ny][nx].m_idx != 0) break;
+	}
+
+	tx = x;
+	ty = y;
+
+	j_ptr = &forge;
+	object_copy(j_ptr, q_ptr);
+	j_ptr->number = 1;
+	
+	for (i = 0; i < n; i++)
+	{
+		if (q_ptr->number < 1) break;
+
+		/* Costs an arrow */
+		q_ptr->number--;
+
+		project(0, 0, y, x, tdam, GF_ARROW, (PROJECT_JUMP | PROJECT_GRID | PROJECT_ITEM | PROJECT_KILL));
+		drop_near(j_ptr, 20, y, x);
+
+		do 
+		{
+			x = tx - 1 + randint0(3);
+			y = ty - 1 + randint0(3);
+		}
+		while (!in_bounds(y, x));
+	}
+
+	return (TRUE);
+}
+
+
 static bool cmd_racial_power_aux(s32b command)
 {
 	s16b        plev = p_ptr->lev;
@@ -474,8 +756,17 @@ static bool cmd_racial_power_aux(s32b command)
 				if (!do_cmd_restore_mana()) return FALSE;
 				break;
 			case CLASS_RANGER:
+				if (!hit_and_away()) return FALSE;
+				break;
 			case CLASS_ARCHER:
-				if (!do_cmd_identify_bows_and_ammos()) return FALSE;
+				if (command == -3)
+				{
+					if (!do_cmd_identify_bows_and_ammos()) return FALSE;
+				}
+				else if (command == -4)
+				{
+					if (!do_cmd_arrow_rain()) return FALSE;
+				}
 				break;
 			case CLASS_ARCHAEOLOGIST:
 				if (command == -3)
@@ -520,6 +811,48 @@ static bool cmd_racial_power_aux(s32b command)
 					break;
 				}
 				break;
+			case CLASS_SNIPER:
+#ifdef JP
+				msg_print("ŨĴ...");
+#else
+				msg_print("You examine your foes...");
+#endif
+				probing();
+				break;
+			case CLASS_SNATCHER:
+				if (command == -3)
+				{
+					bool use_sp = (p_ptr->csp > 0);
+
+					if (!get_aim_dir(&dir)) return FALSE;
+#ifdef JP
+					msg_print("󥸡");
+#else
+					msg_print("SNAAAAAATCH!!!");
+#endif
+					fire_bolt(GF_SNATCH, dir, 0);
+
+					if ((use_sp) && (racial_cost > p_ptr->csp))
+					{
+						racial_cost -= p_ptr->csp;
+						p_ptr->csp = 0;
+						use_sp = FALSE;
+					}
+					if ((!use_sp) && (racial_cost > p_ptr->chp))
+					{
+						racial_cost = p_ptr->chp;
+					}
+				}
+				else if (command == -4)
+				{
+#ifdef JP
+					msg_print("á");
+#else
+					msg_print("Mmmm!");
+#endif
+					teleport_player(5);
+				}
+				break;
 		}
 	}
 	else switch (p_ptr->prace)
@@ -1050,17 +1383,38 @@ void do_cmd_racial_power(void)
 			power_desc[num++].number = -3;
 			break;
 		case CLASS_RANGER:
+#ifdef JP
+			strcpy(power_desc[num].name, "ҥåȡ");
+#else
+			strcpy(power_desc[num].name, "Hit and Away");
+#endif
+			power_desc[num].level = 8;
+			power_desc[num].cost = 12;
+			power_desc[num].stat = A_DEX;
+			power_desc[num].fail = 14;
+			power_desc[num++].number = -3;
+			break;
 		case CLASS_ARCHER:
 #ifdef JP
 			strcpy(power_desc[num].name, "/δ");
 #else
-			strcpy(power_desc[num].name, "Idenfify bows/ammos");
+			strcpy(power_desc[num].name, "Identify bows/ammos");
 #endif
 			power_desc[num].level = 10;
 			power_desc[num].cost = 15;
 			power_desc[num].stat = A_INT;
 			power_desc[num].fail = 15;
 			power_desc[num++].number = -3;
+#ifdef JP
+			strcpy(power_desc[num].name, "α");
+#else
+			strcpy(power_desc[num].name, "Arrow rain");
+#endif
+			power_desc[num].level = 5;
+			power_desc[num].cost = 15;
+			power_desc[num].stat = A_DEX;
+			power_desc[num].fail = 15;
+			power_desc[num++].number = -4;
 			break;
 		case CLASS_ARCHAEOLOGIST:
 #ifdef JP
@@ -1185,6 +1539,43 @@ void do_cmd_racial_power(void)
 				break;
 			}
 			break;
+		case CLASS_SNIPER:
+#ifdef JP
+			strcpy(power_desc[num].name, "󡦥󥹥");
+#else
+			strcpy(power_desc[num].name, "probing");
+#endif
+			power_desc[num].level = 10;
+			power_desc[num].cost = 20;
+			power_desc[num].stat = A_INT;
+			power_desc[num].fail = 12;
+			power_desc[num++].number = -3;
+			break;
+		case CLASS_SNATCHER:
+#ifdef JP
+			strcpy(power_desc[num].name, "ܥǥ");
+#else
+			strcpy(power_desc[num].name, "Body Snathing");
+#endif
+			power_desc[num].level = 1;
+			power_desc[num].cost = (p_ptr->csp) ? p_ptr->csp : p_ptr->chp / 3;
+			power_desc[num].stat = A_INT;
+			power_desc[num].fail = 0;
+			power_desc[num++].number = -3;
+			if (r_info[p_ptr->r_idx].flags1 & (RF1_NEVER_MOVE))
+			{
+#ifdef JP
+				sprintf(power_desc[num].name, "եɥ");
+#else
+				sprintf(power_desc[num].name, "Phase door");
+#endif
+				power_desc[num].level = 1;
+				power_desc[num].cost = 5;
+				power_desc[num].stat = A_INT;
+				power_desc[num].fail = 15;
+				power_desc[num++].number = -4;
+			}
+			break;
 		default:
 #ifdef JP
 			strcpy(power_desc[num].name, "(ʤ)");
