@@ -808,6 +808,9 @@ static void wr_options(void)
 	/* Write "hitpoint_warn" */
 	wr_byte(hitpoint_warn);
 
+	/* Write "spellpoint_warn" */
+	wr_byte(spellpoint_warn);
+
 
 	/*** Cheating options ***/
 
@@ -981,7 +984,7 @@ static void wr_extra(void)
 	wr_s16b(p_ptr->inside_arena);
 	wr_s16b(p_ptr->inside_quest);
 	wr_byte(p_ptr->exit_bldg);
-	wr_byte(p_ptr->leftbldg); /* save building leave status -KMW- */
+	wr_byte(0); /* Unused */
 
 	wr_s16b(p_ptr->oldpx);
 	wr_s16b(p_ptr->oldpy);
@@ -1061,12 +1064,12 @@ static void wr_extra(void)
 
 	wr_s16b(p_ptr->chaos_patron);
 	wr_u32b(p_ptr->muta);
-	wr_u32b(p_ptr->xtra1);
-	wr_u32b(p_ptr->xtra2);
+	wr_u32b(p_ptr->concent);
+	wr_u32b(p_ptr->r_idx);
 
 	wr_byte(p_ptr->confusing);
 	wr_byte(0);     /* oops */
-	wr_byte(0);     /* oops */
+	wr_byte(p_ptr->autopick_autoregister);
 	wr_byte(0);     /* oops */
 	wr_byte(p_ptr->searching);
 	wr_byte(maximize_mode);
@@ -1097,10 +1100,13 @@ static void wr_extra(void)
 	wr_byte(death);
 
 	/* Write feeling */
-	wr_byte(feeling);
+	wr_byte(p_ptr->feeling);
+
+	/* Turn when level began */
+	wr_s32b(old_turn);
 
 	/* Turn of last "feeling" */
-	wr_s32b(old_turn);
+	wr_s32b(p_ptr->feeling_turn);
 
 	/* Current turn */
 	wr_s32b(turn);
@@ -1146,7 +1152,6 @@ static void wr_dungeon(void)
 
 	/* Note that this will induce two wasted bytes */
 	count = 0;
-	prev_char = 0;
 	prev_s16b = 0;
 
 	/* Dump the cave */
@@ -1414,8 +1419,22 @@ static bool wr_savefile_new(void)
 
 	/* Space */
 	wr_u32b(0L);
-	wr_u32b(0L);
+	wr_u16b(0);
+	wr_byte(0);
 
+#ifdef JP
+# ifdef EUC
+	/* EUC kanji code */
+	wr_byte(2);
+# endif
+# ifdef SJIS
+	/* SJIS kanji code */
+	wr_byte(3);
+# endif
+#else
+	/* ASCII */
+	wr_byte(1);
+#endif
 
 	/* Write the RNG state */
 	wr_randomizer();
@@ -1617,7 +1636,7 @@ static bool save_player_aux(char *name)
 {
 	bool    ok = FALSE;
 
-	int             fd = -1;
+	int             fd;
 
 	int             mode = 0644;
 
@@ -2022,9 +2041,6 @@ bool load_player(void)
 			/* Count lives */
 			sf_lives++;
 
-			/* Forget turns */
-			turn = old_turn = 0;
-
 			/* Done */
 			return (TRUE);
 		}
