@@ -1014,7 +1014,7 @@ struct player_type
 	u32b muta;         /* for Chaos mutation */
 
 	u32b concent;      /* for sniper */
-	u32b xtra2;        /* Old mutation */
+	u32b r_idx;        /* for snatcher */
 
 	s16b word_recall;	/* Word of recall counter */
 
@@ -1125,6 +1125,7 @@ struct player_type
 	bool xtra_might;	/* Extra might bow */
 	bool impact;		/* Earthquake blows */
 	bool pass_wall;     /* Permanent wraithform */
+	bool kill_wall;     /* Always digging */
 	bool dec_mana;
 	bool warning;
 
@@ -1155,7 +1156,7 @@ struct player_type
 	s16b skill_tht;		/* Skill: To hit (throwing) */
 	s16b skill_dig;		/* Skill: Digging */
 
-	s16b num_blow;		/* Number of blows */
+	s16b num_blow[2];	/* Number of blows */
 	s16b num_fire;		/* Number of shots */
 
 	byte tval_xtra;		/* Correct xtra tval */
