@@ -3402,6 +3402,32 @@ void do_cmd_spoilers(void)
 			spoil_mon_info("mon-info.spo");
 		}
 
+		/* Test codes for snatcher */
+		else if (i == 's')
+		{
+			int i;
+			char buf[1024];
+			FILE *fff;
+
+			path_build(buf, sizeof(buf), ANGBAND_DIR_USER, "monhds.txt");
+			FILE_TYPE(FILE_TYPE_TEXT);
+			fff = my_fopen(buf, "w");
+			if (fff)
+			{
+				for (i = 1; i < max_r_idx; i++)
+				{
+					int hd = monster_hitdie(i);
+					monster_race *r_ptr = &r_info[i];
+
+					fprintf(fff, "%50s Lv:%3d HD:%3d\n", r_name+r_ptr->name, r_ptr->level, hd);
+				}
+				fclose(fff);
+				msg_print("Successful dump monster HD list.");
+				msg_print(NULL);
+			}
+
+		}
+
 		/* Oops */
 		else
 		{
