@@ -1929,6 +1929,34 @@ void do_cmd_debug(void)
 		do_cmd_wiz_summon(command_arg);
 		break;
 
+	/* Body snatch */
+	case 'S':
+		if (p_ptr->pclass == CLASS_SNATCHER)
+		{
+			if (command_arg)
+			{
+				p_ptr->r_idx = command_arg;
+			}
+			else
+			{
+				char buf[80];
+				sprintf(buf, "%d", p_ptr->r_idx);
+				msg_print(NULL);
+				prt("֡", 0, 0);
+				if (!askfor(buf, 80))
+				{
+					prt("", 0, 0);
+					return;
+				}
+				sscanf(buf, "%d", &p_ptr->r_idx);
+			}
+			restore_level();
+			culc_monster_hitpoints();
+			check_experience();
+			do_cmd_redraw();
+		}
+		break;
+
 	/* Teleport */
 	case 't':
 		teleport_player(100);
