@@ -490,6 +490,7 @@ static void prt_status(void)
 static void prt_title(void)
 {
 	cptr p;
+	char tmp[13];
 
 	/* Wizard */
 	if (wizard)
@@ -514,6 +515,14 @@ static void prt_title(void)
 
 	}
 
+	/* Snatcher */
+	else if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		strncpy(tmp, r_name + r_info[p_ptr->r_idx].name, 12);
+		tmp[12] = '\0';
+		p = tmp;
+	}
+
 	/* Normal */
 	else
 	{
@@ -572,15 +581,23 @@ static void prt_exp(void)
 
 	if (!exp_need)
 	{
+		if ((p_ptr->pclass == CLASS_SNATCHER) && (p_ptr->lev >= SN_MAX_LEVEL))
+		{
+			(void)sprintf(out_val, "********");
+		}		
+		else
+		{
 #ifdef JP
-		(void)sprintf(out_val, "%7ld", (long)p_ptr->exp);
+			(void)sprintf(out_val, "%7ld", (long)p_ptr->exp);
 #else
-		(void)sprintf(out_val, "%8ld", (long)p_ptr->exp);
+			(void)sprintf(out_val, "%8ld", (long)p_ptr->exp);
 #endif
+		}
 	}
 	else
 	{
-		if (p_ptr->lev >= PY_MAX_LEVEL)
+		if ((p_ptr->lev >= PY_MAX_LEVEL) ||
+			((p_ptr->pclass == CLASS_SNATCHER) && (p_ptr->lev >= SN_MAX_LEVEL)))
 		{
 			(void)sprintf(out_val, "********");
 		}		
@@ -713,6 +730,12 @@ static void prt_sp(void)
 	/* Do not show mana unless it matters */
 	if (!mp_ptr->spell_type) return;
 
+	if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		monster_race *r_ptr = &r_info[p_ptr->r_idx];
+		if (!r_ptr->flags4 &&!r_ptr->flags5 &&!r_ptr->flags6) return;
+	}
+
 	/* ȥ */
 #ifdef JP
 	put_str("MP", ROW_CURSP, COL_CURSP);
@@ -1978,6 +2001,19 @@ static void calc_mana(void)
 	{
 		levels = p_ptr->lev;
 	}
+	else if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		monster_race *r_ptr = &r_info[p_ptr->r_idx];
+
+		if (!r_ptr->flags4 && !r_ptr->flags5 && !r_ptr->flags6)
+		{
+			p_ptr->csp = 0;
+			p_ptr->msp = 0;
+			return;
+		}
+
+		levels = p_ptr->lev;
+	}
 	else
 	{
 		/* Extract "effective" player level */
@@ -2001,6 +2037,17 @@ static void calc_mana(void)
 		/* Hack: High mages have a 25% mana bonus */
 		if (msp && (p_ptr->pclass == CLASS_HIGH_MAGE)) msp += msp / 4;
 
+		if (p_ptr->pclass == CLASS_SNATCHER)
+		{
+			monster_race *r_ptr = &r_info[p_ptr->r_idx];
+
+			/* Hack: Smart monsters have a 25% mana bonus */
+			if (r_ptr->flags2 & (RF2_SMART)) msp += msp / 4;
+
+			/* Hack: Smart monsters have a -25% mana bonus */
+			if (r_ptr->flags2 & (RF2_STUPID)) msp -= msp / 4;
+		}
+
 		/* Hack: Dual classess have a -25% mana bonus */
 		if (msp &&
 			((p_ptr->pclass == CLASS_RANGER) ||
@@ -2045,7 +2092,7 @@ static void calc_mana(void)
 		cur_wgt = 0;
 		cur_wgt += inventory[INVEN_BODY].weight;
 		cur_wgt += inventory[INVEN_HEAD].weight;
-		cur_wgt += inventory[INVEN_ARM].weight;
+		if (!is_two_handed()) cur_wgt += inventory[INVEN_ARM].weight;
 		cur_wgt += inventory[INVEN_OUTER].weight;
 		cur_wgt += inventory[INVEN_HANDS].weight;
 		cur_wgt += inventory[INVEN_FEET].weight;
@@ -2076,6 +2123,7 @@ static void calc_mana(void)
 				case CLASS_PRIEST:
 				case CLASS_MINDCRAFTER:
 				case CLASS_ARCHAEOLOGIST:
+				case CLASS_SNATCHER:
 				{
 					msp -= msp * (cur_wgt - max_wgt) / 800;
 					break;
@@ -2568,6 +2616,10 @@ void calc_bonuses(void)
 	bool            old_wraith_form;
 	int             extra_blows;
 	int             extra_shots;
+	int				to_h = 0;
+	int				dis_to_h = 0;
+	int				to_d = 0;
+	int				dis_to_d = 0;
 	object_type     *o_ptr;
 	u32b            f1, f2, f3;
 
@@ -2605,7 +2657,8 @@ void calc_bonuses(void)
 	p_ptr->pspeed = 110;
 
 	/* Start with a single blow per turn */
-	p_ptr->num_blow = 1;
+	p_ptr->num_blow[0] = 1;
+	p_ptr->num_blow[1] = 1;
 
 	/* Start with a single shot per turn */
 	p_ptr->num_fire = 100;
@@ -2624,6 +2677,7 @@ void calc_bonuses(void)
 	p_ptr->xtra_might = FALSE;
 	p_ptr->impact = FALSE;
 	p_ptr->pass_wall = FALSE;
+	p_ptr->kill_wall = FALSE;
 	p_ptr->dec_mana = FALSE;
 	p_ptr->see_inv = FALSE;
 	p_ptr->free_act = FALSE;
@@ -2726,6 +2780,9 @@ void calc_bonuses(void)
 		case CLASS_ELEMENTALIST:
 			element_bonuses();
 			break;
+		case CLASS_SNATCHER:
+			monster_bonuses();
+			break;
 		case CLASS_MONK:
 			/* Unencumbered Monks become faster every 10 levels */
 			if (!(monk_heavy_armor()))
@@ -2811,8 +2868,11 @@ void calc_bonuses(void)
 			p_ptr->resist_conf = TRUE;
 			p_ptr->resist_acid = TRUE;
 
-			/* Klackons become faster */
-			p_ptr->pspeed += (p_ptr->lev) / 10;
+			if (p_ptr->pclass != CLASS_SNATCHER)
+			{
+				/* Klackons become faster */
+				p_ptr->pspeed += (p_ptr->lev) / 10;
+			}
 			break;
 		case RACE_KOBOLD:
 			p_ptr->resist_pois = TRUE;
@@ -3095,7 +3155,9 @@ void calc_bonuses(void)
 		if (f1 & (TR1_SPEED)) p_ptr->pspeed += (s16b) o_ptr->pval;
 
 		/* Affect blows */
-		if (f1 & (TR1_BLOWS)) extra_blows += o_ptr->pval;
+		if ((i != INVEN_WIELD) &&
+			!((i == INVEN_ARM) && is_two_handed()))
+			if (f1 & (TR1_BLOWS)) extra_blows += o_ptr->pval;
 
 		/* Hack -- cause earthquakes */
 		if (f1 & (TR1_IMPACT)) p_ptr->impact = TRUE;
@@ -3178,17 +3240,18 @@ void calc_bonuses(void)
 
 		/* Hack -- do not apply "weapon" bonuses */
 		if (i == INVEN_WIELD) continue;
+		if ((i == INVEN_ARM) && is_two_handed()) continue;
 
 		/* Hack -- do not apply "bow" bonuses */
 		if (i == INVEN_BOW) continue;
 
 		/* Apply the bonuses to hit/damage */
-		p_ptr->to_h += o_ptr->to_h;
-		p_ptr->to_d += o_ptr->to_d;
+		to_h += o_ptr->to_h;
+		to_d += o_ptr->to_d;
 
 		/* Apply the mental bonuses tp hit/damage, if known */
-		if (object_known_p(o_ptr)) p_ptr->dis_to_h += o_ptr->to_h;
-		if (object_known_p(o_ptr)) p_ptr->dis_to_d += o_ptr->to_d;
+		if (object_known_p(o_ptr)) dis_to_h += o_ptr->to_h;
+		if (object_known_p(o_ptr)) dis_to_d += o_ptr->to_d;
 	}
 
 	/* Monks get extra ac for armour _not worn_ */
@@ -3541,14 +3604,13 @@ void calc_bonuses(void)
 
 	/* Actual Modifier Bonuses (Un-inflate stat bonuses) */
 	p_ptr->to_a += ((int)(adj_dex_ta[p_ptr->stat_ind[A_DEX]]) - 128);
-	p_ptr->to_d += ((int)(adj_str_td[p_ptr->stat_ind[A_STR]]) - 128);
-	p_ptr->to_h += ((int)(adj_dex_th[p_ptr->stat_ind[A_DEX]]) - 128);
+	to_d += ((int)(adj_str_td[p_ptr->stat_ind[A_STR]]) - 128);
+	to_h += ((int)(adj_dex_th[p_ptr->stat_ind[A_DEX]]) - 128);
 
 	/* Displayed Modifier Bonuses (Un-inflate stat bonuses) */
 	p_ptr->dis_to_a += ((int)(adj_dex_ta[p_ptr->stat_ind[A_DEX]]) - 128);
-	p_ptr->dis_to_d += ((int)(adj_str_td[p_ptr->stat_ind[A_STR]]) - 128);
-	p_ptr->dis_to_h += ((int)(adj_dex_th[p_ptr->stat_ind[A_DEX]]) - 128);
-
+	dis_to_d += ((int)(adj_str_td[p_ptr->stat_ind[A_STR]]) - 128);
+	dis_to_h += ((int)(adj_dex_th[p_ptr->stat_ind[A_DEX]]) - 128);
 
 	/* Redraw armor (if needed) */
 	if ((p_ptr->dis_ac != old_dis_ac) || (p_ptr->dis_to_a != old_dis_to_a))
@@ -3661,135 +3723,152 @@ void calc_bonuses(void)
 	/* Add all class-specific adjustments to missile Skill. -LM- */
 	p_ptr->skill_thb += add_special_missile_skill(p_ptr->pclass);
 
-
-	/* Examine the "main weapon" */
-	o_ptr = &inventory[INVEN_WIELD];
-
 	/* Assume not heavy */
 	p_ptr->heavy_wield = FALSE;
 
-	/* It is hard to hold a heavy weapon */
-	if (hold < o_ptr->weight / 10)
+	for (i = 0; i < 2; i++)
 	{
-		/* Hard to wield a heavy weapon */
-		p_ptr->to_h += 2 * (hold - o_ptr->weight / 10);
-		p_ptr->dis_to_h += 2 * (hold - o_ptr->weight / 10);
+		if ((i == 1) && !is_two_handed()) break;
 
-		/* Heavy weapon */
-		p_ptr->heavy_wield = TRUE;
+		/* Examine the "main weapon" */
+		o_ptr = &inventory[INVEN_WIELD + i];
 
-		/* The player gets to swing a heavy weapon only once. -LM- */
-		p_ptr->num_blow = 1;
-	}
-
-
-	/* Normal weapons */
-	if (o_ptr->k_idx && !p_ptr->heavy_wield && 
-		  !(p_ptr->pclass == CLASS_MONK && o_ptr->name1 == ART_XIAOLONG))
-	{
-		int str_index, dex_index;
-		int num, wgt, mul, div;
-
-		/* Analyze the class */
-		switch (p_ptr->pclass)
+		/* It is hard to hold a heavy weapon */
+		if (hold < o_ptr->weight / 10)
 		{
-			/* Monk */
-			case CLASS_MONK:
-				num = ((p_ptr->lev < 40) ? 2 : 3); wgt = 40; mul = 40; break;
+			/* Hard to wield a heavy weapon */
+			p_ptr->to_h += 2 * (hold - o_ptr->weight / 10);
+			p_ptr->dis_to_h += 2 * (hold - o_ptr->weight / 10);
 
-			/* Default */
-			default:
-				num = cp_ptr->num; wgt = cp_ptr->wgt; mul = cp_ptr->mul;
+			/* Heavy weapon */
+			p_ptr->heavy_wield = TRUE;
+
+			/* The player gets to swing a heavy weapon only once. -LM- */
+			p_ptr->num_blow[i] = 1;
 		}
 
-		/* Enforce a minimum "weight" (tenth pounds) */
-		div = ((o_ptr->weight < wgt) ? wgt : o_ptr->weight);
-
-		/* Access the strength vs weight */
-		str_index = ((adj_str_blow[p_ptr->stat_ind[A_STR]] * mul / 10) / div);
-
-		/* Maximal value */
-		if (str_index > 11) str_index = 11;
-
-		/* Index by dexterity */
-		dex_index = (adj_dex_blow[p_ptr->stat_ind[A_DEX]]);
-
-		/* Maximal value */
-		if (dex_index > 11) dex_index = 11;
-
-		/* Use the blows table */
-		p_ptr->num_blow = blows_table[str_index][dex_index];
-
-		/* Maximal value */
-		if (p_ptr->num_blow > num) p_ptr->num_blow = num;
-
-		/* Warrior gets one extra attack */
-		if (p_ptr->pclass == CLASS_WARRIOR) p_ptr->num_blow++;
-
-		/* Ranger gets one extra attack with a light weapon */
-		if ((p_ptr->pclass == CLASS_RANGER) && (o_ptr->weight <= 70)) p_ptr->num_blow++;
-
-		/* Archaeologit gets extra attacks with digging */
-		if ((p_ptr->pclass == CLASS_ARCHAEOLOGIST) &&
-			(o_ptr->tval == TV_DIGGING))
+		/* Normal weapons */
+		if (o_ptr->k_idx && !p_ptr->heavy_wield && 
+			  !(p_ptr->pclass == CLASS_MONK && o_ptr->name1 == ART_XIAOLONG))
 		{
-			p_ptr->num_blow++;
-			if (p_ptr->lev >= 30) p_ptr->num_blow++;
-			if (p_ptr->lev >= 45) p_ptr->num_blow++;
+			int str_index, dex_index;
+			int num, wgt, mul, div;
+
+			/* Extract the item flags */
+			object_flags(o_ptr, &f1, &f2, &f3);
+
+			/* Analyze the class */
+			switch (p_ptr->pclass)
+			{
+				/* Monk */
+				case CLASS_MONK:
+					num = ((p_ptr->lev < 40) ? 2 : 3); wgt = 40; mul = 40; break;
+
+				/* Default */
+				default:
+					num = cp_ptr->num; wgt = cp_ptr->wgt; mul = cp_ptr->mul;
+			}
+
+			/* Enforce a minimum "weight" (tenth pounds) */
+			div = ((o_ptr->weight < wgt) ? wgt : o_ptr->weight);
+
+			/* Access the strength vs weight */
+			str_index = ((adj_str_blow[p_ptr->stat_ind[A_STR]] * mul / 10) / div);
+
+			/* When doing two handed combat, you needs more strength. */
+			if (is_two_handed()) str_index = str_index * 3 / 4;
+
+			/* Maximal value */
+			if (str_index > 11) str_index = 11;
+
+			/* Index by dexterity */
+			dex_index = (adj_dex_blow[p_ptr->stat_ind[A_DEX]]);
+
+			/* Maximal value */
+			if (dex_index > 11) dex_index = 11;
+
+			/* Use the blows table */
+			p_ptr->num_blow[i] = blows_table[str_index][dex_index];
+
+			/* Maximal value */
+			if (p_ptr->num_blow[i] > num) p_ptr->num_blow[i] = num;
+
+			/* Warrior gets one extra attack */
+			if (p_ptr->pclass == CLASS_WARRIOR) p_ptr->num_blow[i]++;
+
+			/* Ranger gets one extra attack with a light weapon */
+			if ((p_ptr->pclass == CLASS_RANGER) && (o_ptr->weight <= 70)) p_ptr->num_blow[i]++;
+
+			/* Archaeologit gets extra attacks with digging */
+			if ((p_ptr->pclass == CLASS_ARCHAEOLOGIST) &&
+				(o_ptr->tval == TV_DIGGING))
+			{
+				p_ptr->num_blow[i]++;
+				if (p_ptr->lev >= 30) p_ptr->num_blow[i]++;
+				if (p_ptr->lev >= 45) p_ptr->num_blow[i]++;
+			}
+
+			/* Add in the "bonus blows" */
+			p_ptr->num_blow[i] += extra_blows;
+			if (f1 & (TR1_BLOWS)) p_ptr->num_blow[i] += (s16b)(o_ptr->pval);
+
+			/* Require at least one blow */
+			if (p_ptr->num_blow[i] < 1) p_ptr->num_blow[i] = 1;
+
+			/* Boost digging skill by weapon weight */
+			p_ptr->skill_dig += (o_ptr->weight / 10);
 		}
 
-		/* Add in the "bonus blows" */
-		p_ptr->num_blow += extra_blows;
 
-		/* Require at least one blow */
-		if (p_ptr->num_blow < 1) p_ptr->num_blow = 1;
-
-		/* Boost digging skill by weapon weight */
-		p_ptr->skill_dig += (o_ptr->weight / 10);
-	}
-
-
-	/* Different calculation for monks with empty hands */
-	else if (p_ptr->pclass == CLASS_MONK && monk_empty_hands())
-	{
-		p_ptr->num_blow = 2;
-
-		if (p_ptr->lev > 9) p_ptr->num_blow++;
-		if (p_ptr->lev > 14) p_ptr->num_blow++;
-		if (p_ptr->lev > 24) p_ptr->num_blow++;
-		if (p_ptr->lev > 34) p_ptr->num_blow++;
-		if (p_ptr->lev > 44) p_ptr->num_blow++;
-		if (p_ptr->lev > 49) p_ptr->num_blow++;
-
-		if (monk_heavy_armor()) p_ptr->num_blow /= 2;
-
-		p_ptr->num_blow += extra_blows;
-
-		if (!monk_heavy_armor())
+		/* Different calculation for monks with empty hands */
+		else if (p_ptr->pclass == CLASS_MONK && monk_empty_hands())
 		{
-			p_ptr->to_h += (p_ptr->lev / 3);
-			p_ptr->to_d += (p_ptr->lev / 3);
+			p_ptr->num_blow[i] = 2;
 
-			p_ptr->dis_to_h += (p_ptr->lev / 3);
-			p_ptr->dis_to_d += (p_ptr->lev / 3);
+			if (p_ptr->lev > 9) p_ptr->num_blow[i]++;
+			if (p_ptr->lev > 14) p_ptr->num_blow[i]++;
+			if (p_ptr->lev > 24) p_ptr->num_blow[i]++;
+			if (p_ptr->lev > 34) p_ptr->num_blow[i]++;
+			if (p_ptr->lev > 44) p_ptr->num_blow[i]++;
+			if (p_ptr->lev > 49) p_ptr->num_blow[i]++;
+
+			if (monk_heavy_armor()) p_ptr->num_blow[i] /= 2;
+
+			p_ptr->num_blow[i] += extra_blows;
+
+			if (!monk_heavy_armor())
+			{
+				p_ptr->to_h += (p_ptr->lev / 3);
+				p_ptr->to_d += (p_ptr->lev / 3);
+
+				p_ptr->dis_to_h += (p_ptr->lev / 3);
+				p_ptr->dis_to_d += (p_ptr->lev / 3);
+			}
 		}
-	}
 
-	/* If not wielding a weapon. */
-	else if (!o_ptr->k_idx)
-	{
-		switch(p_ptr->pclass)
+		/* If not wielding a weapon. */
+		else if (!o_ptr->k_idx)
 		{
-			case CLASS_WARRIOR:
-				p_ptr->num_blow = 2;
-			default:
-				p_ptr->num_blow = 1;
+			switch(p_ptr->pclass)
+			{
+				case CLASS_WARRIOR:
+					p_ptr->num_blow[i] = 2;
+					break;
+				case CLASS_SNATCHER:
+					p_ptr->num_blow[i] = monster_blows(p_ptr->r_idx);
+					break;
+				default:
+					p_ptr->num_blow[i] = 1;
+			}
 		}
 	}
 
 	/* Add all other class-specific adjustments to melee Skill. -LM- */
 	p_ptr->skill_thn += add_special_melee_skill(p_ptr->pclass, o_ptr->weight, o_ptr);
 
+	/* Snatcher */
+	if (p_ptr->pclass == CLASS_SNATCHER) p_ptr->skill_thn += add_monster_melee_skill();
+
 	/* Assume okay */
 	p_ptr->icky_wield = FALSE;
 	monk_armour_aux = FALSE;
@@ -3797,27 +3876,36 @@ void calc_bonuses(void)
 	/* Extra bonus for warriors... */
 	if (p_ptr->pclass == CLASS_WARRIOR)
 	{
-		p_ptr->to_h += (p_ptr->lev / 5);
-		p_ptr->to_d += (p_ptr->lev / 5);
+		to_h += (p_ptr->lev / 5);
+		to_d += (p_ptr->lev / 5);
 
-		p_ptr->dis_to_h += (p_ptr->lev / 5);
-		p_ptr->dis_to_d += (p_ptr->lev / 5);
+		dis_to_h += (p_ptr->lev / 5);
+		dis_to_d += (p_ptr->lev / 5);
 	}
 
 	/* Priest weapon penalty for non-blessed edged weapons */
-	if ((p_ptr->pclass == CLASS_PRIEST) && (!p_ptr->bless_blade) &&
-		 ((o_ptr->tval == TV_SWORD) || (o_ptr->tval == TV_POLEARM)))
+	if (p_ptr->pclass == CLASS_PRIEST)
 	{
-		/* Reduce the real bonuses */
-		p_ptr->to_h -= 2;
-		p_ptr->to_d -= 2;
+		for (i = 0; i < 2; i++)
+		{
+			o_ptr = &inventory[INVEN_WIELD + i];
+			object_flags(o_ptr, &f1, &f2, &f3);
 
-		/* Reduce the mental bonuses */
-		p_ptr->dis_to_h -= 2;
-		p_ptr->dis_to_d -= 2;
+			if (!(f3 & (TR3_BLESSED)) &&
+				 ((o_ptr->tval == TV_SWORD) || (o_ptr->tval == TV_POLEARM)))
+			{
+				/* Reduce the real bonuses */
+				p_ptr->to_h -= 2;
+				p_ptr->to_d -= 2;
 
-		/* Icky weapon */
-		p_ptr->icky_wield = TRUE;
+				/* Reduce the mental bonuses */
+				p_ptr->dis_to_h -= 2;
+				p_ptr->dis_to_d -= 2;
+
+				/* Icky weapon */
+				p_ptr->icky_wield = TRUE;
+			}
+		}
 	}
 
 	if (monk_heavy_armor())
@@ -3825,6 +3913,57 @@ void calc_bonuses(void)
 		monk_armour_aux = TRUE;
 	}
 
+	/* Add all to_hit and to_dam bonuses. */
+	if (is_two_handed())
+	{
+		to_d /= 2;
+		to_h /= 2;
+		dis_to_d /= 2;
+		dis_to_h /= 2;
+
+		/* When doing two handed combat, get penalty to to-hit. */
+		to_h -= 10;
+		dis_to_h -= 10;
+	}
+
+	p_ptr->to_d += to_d;
+	p_ptr->to_h += to_h;
+	p_ptr->dis_to_d += dis_to_d;
+	p_ptr->dis_to_h += dis_to_h;
+
+	/* Specified weapons give extra bonuses when doing two handed combat. */
+	if (is_two_handed())
+	{
+		object_type *o1_ptr = &inventory[INVEN_WIELD];
+		object_type *o2_ptr = &inventory[INVEN_ARM];
+
+		if ((o1_ptr->name1 == ART_QUICKTHORN) && (o2_ptr->name1 == ART_LITTLETHORN))
+		{
+			p_ptr->to_h += 10;
+			p_ptr->dis_to_h += 10;
+			p_ptr->to_a += 10;
+			p_ptr->dis_to_a += 10;
+			p_ptr->pspeed += 7;
+		}
+		else if ((o1_ptr->name1 == ART_ICINGDEATH) && (o2_ptr->name1 == ART_TWINKLE))
+		{
+			p_ptr->to_h += 10;
+			p_ptr->dis_to_h += 10;
+			p_ptr->to_a += 5;
+			p_ptr->dis_to_a += 5;
+			p_ptr->pspeed += 5;
+		}
+		else if ((o2_ptr->tval == TV_SWORD) && (o2_ptr->sval == SV_MAIN_GAUCHE))
+		{
+			p_ptr->to_h += 5;
+			p_ptr->dis_to_h += 5;
+			p_ptr->to_a += 5;
+			p_ptr->dis_to_a += 5;
+		}
+
+		p_ptr->redraw |= (PR_ARMOR | PR_SPEED);
+	}
+
 	/* Affect Skill -- stealth (bonus one) */
 	p_ptr->skill_stl += 1;
 
