@@ -48,7 +48,20 @@ static void choice_gain_stat(void)
 		prt("", 8, 14);
 		prt("        ɤǽͤ夲ޤ", 1, 14);
 #else
-		/* Nanka */
+		cnv_stat(p_ptr->stat_max[0], tmp);
+		prt(format("        a) Str (cur %s)", tmp), 2, 14);
+		cnv_stat(p_ptr->stat_max[1], tmp);
+		prt(format("        b) Int (cur %s)", tmp), 3, 14);
+		cnv_stat(p_ptr->stat_max[2], tmp);
+		prt(format("        c) Wis (cur %s)", tmp), 4, 14);
+		cnv_stat(p_ptr->stat_max[3], tmp);
+		prt(format("        d) Dex (cur %s)", tmp), 5, 14);
+		cnv_stat(p_ptr->stat_max[4], tmp);
+		prt(format("        e) Con (cur %s)", tmp), 6, 14);
+		cnv_stat(p_ptr->stat_max[5], tmp);
+		prt(format("        f) Chr (cur %s)", tmp), 7, 14);
+		prt("", 8, 14);
+		prt("        Which stat do you want to raise?", 1, 14);
 #endif
 
 		/* Choice */
@@ -64,7 +77,11 @@ static void choice_gain_stat(void)
 				prt("",n+2,14);
 
 		/* Confirm */
+#ifdef JP
 		if (get_check("Ǥ")) break;
+#else
+		if (get_check("Are you sure? ")) break;
+#endif
 	}
 
 	/* Gain stat */
@@ -93,6 +110,12 @@ void check_experience(void)
 	/* Hack -- upper limit */
 	if (p_ptr->exp > PY_MAX_EXP) p_ptr->exp = PY_MAX_EXP;
 
+	if (p_ptr->pclass == CLASS_SNATCHER)
+	{
+		if (p_ptr->exp > (player_exp[SN_MAX_LEVEL - 1] * p_ptr->expfact / 100L - 1L))
+			p_ptr->exp = (player_exp[SN_MAX_LEVEL - 1] * p_ptr->expfact / 100L - 1L);
+	}
+
 	/* Hack -- upper limit */
 	if (p_ptr->max_exp > PY_MAX_EXP) p_ptr->max_exp = PY_MAX_EXP;
 
@@ -111,7 +134,8 @@ void check_experience(void)
 
 	/* Lose levels while possible */
 	while ((p_ptr->lev > 1) &&
-	       (p_ptr->exp < (player_exp[p_ptr->lev - 2] * p_ptr->expfact / 100L)))
+		((p_ptr->exp < (player_exp[p_ptr->lev - 2] * p_ptr->expfact / 100L)) ||
+		((p_ptr->pclass == CLASS_SNATCHER) && (p_ptr->lev > SN_MAX_LEVEL))))
 	{
 		/* Lose a level */
 		p_ptr->lev--;
@@ -135,6 +159,9 @@ void check_experience(void)
 	while ((p_ptr->lev < PY_MAX_LEVEL) &&
 	       (p_ptr->exp >= (player_exp[p_ptr->lev-1] * p_ptr->expfact / 100L)))
 	{
+		if ((p_ptr->pclass == CLASS_SNATCHER) && (p_ptr->lev >= SN_MAX_LEVEL))
+			break;
+
 		/* Gain a level */
 		p_ptr->lev++;
 		lite_spot(py, px);
@@ -212,6 +239,18 @@ void check_experience(void)
 			(void)gain_random_mutation(0);
 			level_mutation = FALSE;
 		}
+
+		if ((p_ptr->pclass == CLASS_SNATCHER) && (p_ptr->lev < PY_MAX_LEVEL))
+		{
+			if (p_ptr->lev >= SN_MAX_LEVEL)
+			{
+#ifdef JP
+				msg_print("οΤǤϤʾ嶯ʤʤ");
+#else
+				msg_print("Can not level up with this body.");
+#endif
+			}
+		}
 	}
 
 	/* Redraw experience */
@@ -322,96 +361,24 @@ static bool kind_is_good_book(int k_idx)
 	return (FALSE);
 }
 
-/*
- * Handle the "death" of a monster.
- *
- * Disperse treasures centered at the monster location based on the
- * various flags contained in the monster flags fields.
- *
- * Check for "Quest" completion when a quest monster is killed.
- *
- * Note that only the player can induce "monster_death()" on Uniques.
- * Thus (for now) all Quest monsters should be Uniques.
- *
- * Note that monsters can now carry objects, and when a monster dies,
- * it drops all of its objects, which may disappear in crowded rooms.
- */
-void monster_death(int m_idx, bool drop_item_okay)
+
+
+void check_quest_completion(monster_type *m_ptr)
 {
-	int i, j, y, x, ny, nx, i2, j2;
-
-	int dump_item = 0;
-	int dump_gold = 0;
-
-	int number_mon;
-
-	int number = 0;
-
-	monster_type *m_ptr = &m_list[m_idx];
-
-	monster_race *r_ptr = &r_info[m_ptr->r_idx];
-
-	bool visible = (m_ptr->ml || (r_ptr->flags1 & RF1_UNIQUE));
-
-	bool good = (r_ptr->flags1 & RF1_DROP_GOOD) ? TRUE : FALSE;
-	bool great = (r_ptr->flags1 & RF1_DROP_GREAT) ? TRUE : FALSE;
-
-	bool do_gold = (!(r_ptr->flags1 & RF1_ONLY_ITEM));
-	bool do_item = (!(r_ptr->flags1 & RF1_ONLY_GOLD));
-	bool cloned = FALSE;
-	bool create_stairs = FALSE;
-	bool reward = FALSE;
-	int force_coin = get_coin_type(m_ptr->r_idx);
+	int i, y, x, ny, nx, i2, j2;
 
 	int quest_num;
 
+	bool create_stairs = FALSE;
+	bool reward = FALSE;
+
 	object_type forge;
 	object_type *q_ptr;
 
-
-	/* Notice changes in view */
-	if (r_ptr->flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_1 | RF7_SELF_LITE_2))
-	{
-		/* Update some things */
-		p_ptr->update |= (PU_MON_LITE);
-	}
-
 	/* Get the location */
 	y = m_ptr->fy;
 	x = m_ptr->fx;
 
-	/* Handle the possibility of player vanquishing arena combatant -KMW- */
-	if (p_ptr->inside_arena)
-	{
-		p_ptr->exit_bldg = TRUE;
-#ifdef JP
-		msg_print("ԥؤƻʤǤ롣");
-#else
-		msg_print("Victorious! You're on your way to becoming Champion.");
-#endif
-		p_ptr->arena_number++;
-	}
-
-	if (m_ptr->smart & SM_CLONED)
-		cloned = TRUE;
-
-	/* Let monsters explode! */
-	for (i = 0; i < 4; i++)
-	{
-		if (r_ptr->blow[i].method == RBM_EXPLODE)
-		{
-			u16b flg = PROJECT_GRID | PROJECT_ITEM | PROJECT_KILL;
-			int typ = mbe_info[r_ptr->blow[i].effect].explode_type;
-			int d_dice = r_ptr->blow[i].d_dice;
-			int d_side = r_ptr->blow[i].d_side;
-			int damage = damroll(d_dice, d_side);
-
-			sound(SOUND_EXPLODE);
-			project(m_idx, 3, y, x, damage, typ, flg);
-			break;
-		}
-	}
-
 	/* Inside a quest */
 	quest_num = p_ptr->inside_quest;
 
@@ -501,17 +468,18 @@ void monster_death(int m_idx, bool drop_item_okay)
 			}
 			case QUEST_TYPE_KILL_ALL:
 			{
-				number_mon = 0;
+				int number_mon = 0;
+
+				if (!is_hostile(m_ptr)) break;
 
 				/* Count all hostile monsters */
 				for (i2 = 0; i2 < cur_wid; ++i2)
 					for (j2 = 0; j2 < cur_hgt; j2++)
 						if (cave[j2][i2].m_idx > 0)
-							if (is_hostile(&m_list[cave[j2][i2].m_idx])
-								&& cave[j2][i2].m_idx!=m_idx)
-									number_mon++;
+							if (is_hostile(&m_list[cave[j2][i2].m_idx]))
+								number_mon++;
 
-				if (number_mon == 0)
+				if ((number_mon - 1) == 0)
 				{
 					/* completed */
 					if (quest[i].flags & QUEST_FLAG_SILENT)
@@ -675,6 +643,117 @@ void monster_death(int m_idx, bool drop_item_okay)
 		p_ptr->update |= (PU_VIEW | PU_LITE | PU_FLOW | PU_MON_LITE | PU_MONSTERS);
 	}
 
+	/*
+	 * Drop quest reward
+	 */
+	if (reward)
+	{
+		int reward_num = MAX((dun_level / 10) + 1, 2);
+
+		while(reward_num --)
+		{
+			/* Get local object */
+			q_ptr = &forge;
+
+			/* Wipe the object */
+			object_wipe(q_ptr);
+
+			/* Make a great object */
+			make_object(q_ptr, TRUE, TRUE);
+
+			/* Drop it in the dungeon */
+			(void)drop_near(q_ptr, -1, y, x);
+		}
+	}
+}
+
+/*
+ * Handle the "death" of a monster.
+ *
+ * Disperse treasures centered at the monster location based on the
+ * various flags contained in the monster flags fields.
+ *
+ * Check for "Quest" completion when a quest monster is killed.
+ *
+ * Note that only the player can induce "monster_death()" on Uniques.
+ * Thus (for now) all Quest monsters should be Uniques.
+ *
+ * Note that monsters can now carry objects, and when a monster dies,
+ * it drops all of its objects, which may disappear in crowded rooms.
+ */
+void monster_death(int m_idx, bool drop_item_okay)
+{
+	int i, j, y, x;
+
+	int dump_item = 0;
+	int dump_gold = 0;
+
+	int number = 0;
+
+	monster_type *m_ptr = &m_list[m_idx];
+
+	monster_race *r_ptr = &r_info[m_ptr->r_idx];
+
+	bool visible = (m_ptr->ml || (r_ptr->flags1 & RF1_UNIQUE));
+
+	bool good = (r_ptr->flags1 & RF1_DROP_GOOD) ? TRUE : FALSE;
+	bool great = (r_ptr->flags1 & RF1_DROP_GREAT) ? TRUE : FALSE;
+
+	bool do_gold = (!(r_ptr->flags1 & RF1_ONLY_ITEM));
+	bool do_item = (!(r_ptr->flags1 & RF1_ONLY_GOLD));
+	bool cloned = FALSE;
+	int force_coin = get_coin_type(m_ptr->r_idx);
+
+	object_type forge;
+	object_type *q_ptr;
+
+
+	/* Notice changes in view */
+	if (r_ptr->flags7 & (RF7_HAS_LITE_1 | RF7_HAS_LITE_2 | RF7_SELF_LITE_1 | RF7_SELF_LITE_2))
+	{
+		/* Update some things */
+		p_ptr->update |= (PU_MON_LITE);
+	}
+
+	/* Get the location */
+	y = m_ptr->fy;
+	x = m_ptr->fx;
+
+	/* Handle the possibility of player vanquishing arena combatant -KMW- */
+	if (p_ptr->inside_arena)
+	{
+		p_ptr->exit_bldg = TRUE;
+#ifdef JP
+		msg_print("ԥؤƻʤǤ롣");
+#else
+		msg_print("Victorious! You're on your way to becoming Champion.");
+#endif
+		p_ptr->arena_number++;
+	}
+
+	if (m_ptr->smart & SM_CLONED)
+		cloned = TRUE;
+
+	/* Let monsters explode! */
+	for (i = 0; i < 4; i++)
+	{
+		if (r_ptr->blow[i].method == RBM_EXPLODE)
+		{
+			u16b flg = PROJECT_GRID | PROJECT_ITEM | PROJECT_KILL;
+			int typ = mbe_info[r_ptr->blow[i].effect].explode_type;
+			int d_dice = r_ptr->blow[i].d_dice;
+			int d_side = r_ptr->blow[i].d_side;
+			int damage = damroll(d_dice, d_side);
+
+			sound(SOUND_EXPLODE);
+			project(m_idx, 3, y, x, damage, typ, flg);
+			break;
+		}
+	}
+
+	/* Check for quest completion */
+	check_quest_completion(m_ptr);
+
 #ifdef USE_CORPSES
 	/* Drop a dead corpse? */
 	if ((randint1(r_ptr->flags1 & RF1_UNIQUE ? 1 : 4) == 1) &&
@@ -1002,7 +1081,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 
 			case MON_OROCHI:
 				a_idx = ART_KUSANAGI;
-				chance = 20;
+				chance = 10;
 				break;
 
 			case MON_GOTHMOG:
@@ -1042,7 +1121,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 
 			case MON_YAMATO_TAKERU:
 				a_idx = ART_KUSANAGI;
-				chance = 10;
+				chance = 5;
 				break;
 
 			case MON_MIKADUCHI:
@@ -1057,7 +1136,7 @@ void monster_death(int m_idx, bool drop_item_okay)
 
 			case MON_SUSANOO:
 				a_idx = ART_KUSANAGI;
-				chance = 10;
+				chance = 5;
 				break;
 
 			case MON_TSUKUYOMI:
@@ -1150,29 +1229,6 @@ void monster_death(int m_idx, bool drop_item_okay)
 		lore_treasure(m_idx, dump_item, dump_gold);
 	}
 
-	/*
-	 * Drop quest reward
-	 */
-	if (reward)
-	{
-		int reward_num = MAX((dun_level / 10) + 1, 2);
-
-		while(reward_num --)
-		{
-			/* Get local object */
-			q_ptr = &forge;
-
-			/* Wipe the object */
-			object_wipe(q_ptr);
-
-			/* Make a great object */
-			make_object(q_ptr, TRUE, TRUE);
-
-			/* Drop it in the dungeon */
-			(void)drop_near(q_ptr, -1, y, x);
-		}
-	}
-
 	/* Only process "Quest Monsters" */
 	if (!(r_ptr->flags1 & RF1_QUESTOR)) return;
 
@@ -2978,11 +3034,10 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 				/* Get the quest text */
 				init_flags = INIT_SHOW_TEXT;
 				quest_text_line = 0;
+				process_dungeon_file("q_info.txt", 0, 0, 0, 0);
 #ifdef JP
-				process_dungeon_file("q_info_j.txt", 0, 0, 0, 0);
 				name = format("ȡ%s(%d)", quest[c_ptr->special].name, quest[c_ptr->special].level);
 #else
-				process_dungeon_file("q_info.txt", 0, 0, 0, 0);
 				name = format("quest '%s'(level %d)", quest[c_ptr->special].name, quest[c_ptr->special].level);
 #endif
 
@@ -3046,6 +3101,12 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 				sprintf(out_val, "%s%s%s%s [%s] (%d:%d)", s1, name, s2, s3, info, y, x);
 #else
 				sprintf(out_val, "%s%s%s%s [%s] (%d:%d)", s1, s2, s3, name, info, y, x);
+#endif
+			else if ((p_ptr->pclass == CLASS_SNATCHER) && ((y == py) && (x == px)))
+#ifdef JP
+				sprintf(out_val, "%s%s%s%s[r %s]", s1, name, s2, s3, info);
+#else
+				sprintf(out_val, "%s%s%s%s [r,%s]", s1, s2, s3, name, info);
 #endif
 			else
 #ifdef JP
@@ -3057,6 +3118,32 @@ static int target_set_aux(int y, int x, int mode, cptr info)
 			move_cursor_relative(y, x);
 			query = inkey();
 
+			if ((p_ptr->pclass == CLASS_SNATCHER) && ((y == py) && (x == px)))
+			{
+				/* Recall */
+				if (query == 'r')
+				{
+					/* Save */
+					screen_save();
+
+					/* Recall on screen */
+					screen_roff(p_ptr->r_idx, 0);
+
+					/* Hack -- Complete the prompt (again) */
+#ifdef JP
+					Term_addstr(-1, TERM_WHITE, format("  [r %s%s]", x_info, info));
+#else
+					Term_addstr(-1, TERM_WHITE, format("  [r,%s%s]", x_info, info));
+#endif
+
+					/* Command */
+					query = inkey();
+
+					/* Restore */
+					screen_load();
+				}
+			}
+
 			/* Always stop at "normal" keys */
 			if ((query != '\r') && (query != '\n') && (query != ' ')) break;
 		}
